--[[
##################
PsychoUI: keivamp#
##################
]]--
local PsychoUI = LibStub("AceAddon-3.0"):GetAddon("PsychoUI")
local LSM = LibStub("LibSharedMedia-3.0")

function PsychoUI:GetOptions()
    local db = self.db.char
    local options = {
        name = "PsychoUI",
        handler = PsychoUI,
        type = "group",
        args = {
            lockframes = {
                        order = 1,
                        name = "lockframes",
                        desc = "Turn off to move elements, turn on to lock elements in place - This wil Reload your UI to adjust the settings properly",
                        type = "toggle",
                        width = "double",
                        get = function() return db.lockframes  end,
                        set = function(info, value) db.lockframes = value ReloadUI() end
                    },
			XPBar = {
                order = 1,
                name = "Xp Bar",
                type = "group",
                args = {
                    UsePsychoUIXP = {
                        order = 2,
                        name = "Use PsychoUI XP",
                        desc = "The really cool XP bar - Turning this off diables the bar",
                        type = "toggle",
                        width = "single",
                        get = function() return db.UsePsychoUIXP end,
                        set = function(info, value) db.UsePsychoUIXP = value end
                    },
					ReloadReminder = {
                        order = 1,
                        name = "Remember to Reload the UI (/rl) after adjusting the settings",
						fontSize  = "large",
                        desc = "Remember to Reload",
                        descStyle = "inline",
                        type = "description",
                        width = "full",
                       
                    },
					XPCustomFont = {
                        order = 3,
                        name = "Font",
                        desc = "Use the Custom Font",
                        type = "toggle",
                        width = "single",
                        get = function() return db.XPCustomFont end,
                        set = function(info, value) db.XPCustomFont = value end
                    },
					XPMoveY = {
                        order = 4,
                        name = "Move Up and Down",
                        desc = "Move the XP Bar up and down",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.XPMoveY end,
                        set = function(info, value) db.XPMoveY = value end
                    },
					XPMoveX = {
                        order = 5,
                        name = "Left And Right",
                        desc = "Move the XP Bar left and right",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.XPMoveX end,
                        set = function(info, value) db.XPMoveX = value end
                    },
					XPWidth = {
                        order = 6,
                        name = "Width",
                        desc = "How wide do you want it?",
                        type = "range",
                        width = "double",
						min = 5,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.XPWidth end,
                        set = function(info, value) db.XPWidth = value end
                    },
					XPHeight = {
                        order = 7,
                        name = "Height",
                        desc = "How tall do you want this bar?",
                        type = "range",
                        width = "double",
						min = 5,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.XPHeight end,
                        set = function(info, value) db.XPHeight = value end
                    },
					 ShowRested = {
                        order = 8,
                        name = "Show Rested XP",
                        desc = "Displays the rested XP amount if any",
                        type = "toggle",
                        width = "single",
                        get = function() return db.ShowRested end,
                        set = function(info, value) db.ShowRested = value end
                    },
					ShowMaxXP = {
                        order = 9,
                        name = "Show Needed XP",
                        desc = "Displays how much total XP is need to get to the next level on the right",
                        type = "toggle",
                        width = "single",
                        get = function() return db.ShowMaxXP end,
                        set = function(info, value) db.ShowMaxXP = value end
                    },
					ShowMinXP = {
                        order = 10,
                        name = "Show Current",
                        desc = "Displays your current xp on the left",
                        type = "toggle",
                        width = "single",
                        get = function() return db.ShowMinXP end,
                        set = function(info, value) db.ShowMinXP = value end
                    },
					XPStatusBar = {
						order = 11,
						type = 'select',
						 dialogControl = 'LSM30_Statusbar', 
						  name = 'Status Bar Type',
						 desc = 'Status Bars for peeps who like to change Bars',
						 values = LSM:HashTable("statusbar"),			 
						  get = function()
							  return db.XPStatusBar -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.XPStatusBar = key -- saves our new selection the the current one
						 end,
					},
					font = {
				    order = 12,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Font Name',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.XPFontKey -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.XPFontKey = key -- saves our new selection the the current one
						 end,
					},
					XPFontOutline = {
					order = 13,
						type = 'select',
						name = 'Font Outline',
						desc = 'Outlines for the fonts',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.XPFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							
							  db.XPFontOutline = key -- saves our new selection the the current one
							-- print(key)
						 end,
					},
					XPFontSize = {
                        order = 14,
                        name = "Font Size",
                        desc = "Size of the font",
                        type = "range",
                        width = "double",
						min = 6,
						max = 100,
						softMin = 6,
						softMax  = 100,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.XPFontSize end,
                        set = function(info, value) db.XPFontSize = value end
                    },
					XPTextY = {
                        order = 15,
                        name = "Text UP&DOWN!",
                        desc = "Bump the text UP and DOWN!!!!",
                        type = "range",
                        width = "double",
						min = -20,
						max = 20,
						softMin = -20,
						softMax  = 20,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.XPTextY end,
                        set = function(info, value) db.XPTextY = value end
                    },
					VERTICAL = {
                        order = 16,
                        name = "VERTICAL XP Bar",
                        desc = "VERTICAL - Make sure you adjust the width and height",
                        type = "toggle",
                        width = "double",
                        get = function() return db.UseVertXP end,
                        set = function(info, value) db.UseVertXP = value end
                    }
             
                }
            },
			RepBar = {
                order = 20,
                name = "Rep Bar",
                type = "group",
                args = {
				ReloadReminder = {
                        order = 1,
                        name = "Remember to Reload the UI (/rl) after adjusting the settings",
						fontSize  = "large",
                        desc = "Remember to Reload",
                        descStyle = "inline",
                        type = "description",
                        width = "full",
                       
                    },
                    UsePsychoUIRep = {
                        order = 21,
                        name = "Use PsychoUI Rep",
                        desc = "The really cool Rep bar",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.UsePsychoUIRep end,
                        set = function(info, value) db.UsePsychoUIRep = value end
                    },
					RepCustomFont = {
                        order = 22,
                        name = "Font",
                        desc = "Use the Custom Font",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.RepCustomFont end,
                        set = function(info, value) db.RepCustomFont = value end
                    },
					RepMoveY = {
                        order = 23,
                        name = "Move Up and Down",
                        desc = "Move the Rep Bar up and down",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.RepMoveY end,
                        set = function(info, value) db.RepMoveY = value end
                    },
					RepMoveX = {
                        order = 24,
                        name = "Left And Right",
                        desc = "Move the Rep Bar left and right",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.RepMoveX end,
                        set = function(info, value) db.RepMoveX = value end
                    },
					RepWidth = {
                        order = 25,
                        name = "Width",
                        desc = "How wide do you want it?",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.RepWidth end,
                        set = function(info, value) db.RepWidth = value end
                    },
					RepHeight = {
                        order = 26,
                        name = "Height",
                        desc = "How tall do you want this bar?",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min =5,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.RepHeight end,
                        set = function(info, value) db.RepHeight = value end
                    },
					 ShowFactionName = {
                        order = 27,
                        name = "Show Rep Faction",
                        desc = "Displays the Rep Faction",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.ShowFactionName end,
                        set = function(info, value) db.ShowFactionName = value end
                    },
					ShowMaxRep = {
                        order = 28,
                        name = "Show Needed Rep",
                        desc = "Displays how much total Rep is need to get to the next level on the right",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.ShowMaxRep end,
                        set = function(info, value) db.ShowMaxRep = value end
                    },
					ShowMinRep = {
                        order = 29,
                        name = "Show Current Rep",
                        desc = "Displays your current Rep on the left",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.ShowMinRep end,
                        set = function(info, value) db.ShowMinRep = value end
                    },
					RepStatusBar = {
						order = 30,
						type = 'select',
						 dialogControl = 'LSM30_Statusbar', 
						 name = 'Status Bar Type',
						 desc = 'Status Bars for peeps who like to change Bars',
						 values = LSM:HashTable("statusbar"),				 
						  get = function()
							  return db.RepStatusBar -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.RepStatusBar = key -- saves our new selection the the current one
						 end,
					},
					font = {
				    order = 31,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Font Name',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.RepFontKey -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.RepFontKey = key -- saves our new selection the the current one
						 end,
					},
					RepFontOutline = {
					order = 32,
						type = 'select',
						name = 'Font Outline',
						desc = 'Outlines for the fonts',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.RepFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.RepFontOutline = key -- saves our new selection the the current one
						 end,
					},
					RepFontSize = {
                        order = 33,
                        name = "Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 6,
						max = 100,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.RepFontSize end,
                        set = function(info, value) db.RepFontSize = value end
                    },
					RepTextY = {
                        order = 34,
                        name = "Text UP&DOWN!",
                        desc = "Bump the text UP and DOWN!!!!",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -20,
						max = 20,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.RepTextY end,
                        set = function(info, value) db.RepTextY = value end
                    },
					RepVERTICAL = {
                        order = 35,
                        name = "VERTICAL Rep",
                        desc = "VERTICAL Rep",
                        descStyle = "inline",
                        type = "toggle",
                        width = "double",
                        get = function() return db.UseVertRep end,
                        set = function(info, value) db.UseVertRep = value end
                    }
             
                }
            },
			AzeBar = {
                order = 40,
                name = "Azerite Bar",
                type = "group",
                args = {
                   ReloadReminder = {
                        order = 1,
                        name = "Remember to Reload the UI (/rl) after adjusting the settings",
						fontSize  = "large",
                        desc = "Remember to Reload",
                        descStyle = "inline",
                        type = "description",
                        width = "full",
                       
                    },
                    UsePsychoUIAze = {
                        order = 41,
                        name = "Use PsychoUI Azerite",
                        desc = "The really cool Azerite bar",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.UsePsychoUIAze end,
                        set = function(info, value) db.UsePsychoUIAze = value end
                    },
					AzeCustomFont = {
                        order = 42,
                        name = "Font",
                        desc = "Use the Custom Font",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.AzeCustomFont end,
                        set = function(info, value) db.AzeCustomFont = value end
                    },
					AzeMoveY = {
                        order = 43,
                        name = "UP&DOWN!",
                        desc = "UP and DOWN!!!!",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.AzeMoveY end,
                        set = function(info, value) db.AzeMoveY = value end
                    },
					AzeMoveX = {
                        order = 44,
                        name = "LEFT&RIGHT!",
                        desc = " Bar LEFT and RIGHT!!!!",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.AzeMoveX end,
                        set = function(info, value) db.AzeMoveX = value end
                    },
					AzeWidth = {
                        order = 45,
                        name = "Width",
                        desc = "Bar Width!!!!",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.AzeWidth end,
                        set = function(info, value) db.AzeWidth = value end
                    },
					AzeHeight = {
                        order = 46,
                        name = "Height",
                        desc = "Bar Height!!!!",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.AzeHeight end,
                        set = function(info, value) db.AzeHeight = value end
                    },
					 AzeritePower = {
                        order = 47,
                        name = "Show Azerite Level",
                        desc = "Displays the Azerite Level",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.AzeritePower end,
                        set = function(info, value) db.AzeritePower = value end
                    },
					ShowMaxAze = {
                        order = 48,
                        name = "Show Needed Azerite",
                        desc = "Displays how much total Azerite is need to get to the next level on the right",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.ShowMaxAze end,
                        set = function(info, value) db.ShowMaxAze = value end
                    },
					ShowMinAze = {
                        order = 49,
                        name = "Show Current Azerite",
                        desc = "Displays your current Azerite on the left",
                        descStyle = "inline",
                        type = "toggle",
                        width = "double",
                        get = function() return db.ShowMinAze end,
                        set = function(info, value) db.ShowMinAze = value end
                    },
					AzeStatusBar = {
						order = 50,
						type = 'select',
						 dialogControl = 'LSM30_Statusbar', 
						 name = 'Status Bar Type',
						 desc = 'Status Bars for peeps who like to change Bars',
						 values = LSM:HashTable("statusbar"),			 
						  get = function()
							  return db.AzeStatusBar -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.AzeStatusBar = key -- saves our new selection the the current one
						 end,
					},
					font = {
				    order = 51,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Font Name',
						 desc = 'Fonts for peeps who like to change fonts',
						  values = LSM:HashTable("font"),						 
						  get = function()
							  return db.AzeFontKey -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.AzeFontKey = key -- saves our new selection the the current one
						 end,
					},
					AzeFontOutline = {
					order = 52,
						type = 'select',
						name = 'Font Outline',
						desc = 'Outlines for the fonts',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.AzeFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							
							  db.AzeFontOutline = key -- saves our new selection the the current one
							-- print(key)
						 end,
					},
					AzeFontSize = {
                        order = 53,
                        name = "Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 6,
						max = 100,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.AzeFontSize end,
                        set = function(info, value) db.AzeFontSize = value end
                    },
					AzeTextY = {
                        order = 54,
                        name = "Bump Text UP & DOWN!",
                        desc = "Bump the text UP and DOWN!!!!",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -20,
						max = 20,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.AzeTextY end,
                        set = function(info, value) db.AzeTextY = value end
                    },
					AzeVERTICAL = {
                        order = 55,
                        name = "VERTICAL Rep",
                        desc = "VERTICAL Azerite",
                        descStyle = "inline",
                        type = "toggle",
                        width = "double",
                        get = function() return db.UseVertAze end,
                        set = function(info, value) db.UseVertAze = value end
                    }
             
                }
            },
			MicroMenu = {
                order = 60,
                name = "Micro Menu",
                type = "group",
                args = {
				ReloadReminder = {
                        order = 1,
                        name = "Remember to Reload the UI (/rl) after adjusting the settings",
						fontSize  = "large",
                        desc = "Remember to Reload",
                        descStyle = "inline",
                        type = "description",
                        width = "full",
                       
                    },
                     MicroDisable = {
                        order = 2,
                        name = "Disable",
                        desc = "Disable the MicroMenu",
                        descStyle = "inline",
                        type = "toggle",
                        width = "double",
                        get = function() return db.MicroDisable end,
                        set = function(info, value) db.MicroDisable = value end
                     },
					  MicroX = {
                        order = 3,
                        name = "MicroMenu Left and Right",
                        desc = "Set the Left and Right point of the MicroMenu if enabled",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.MicroX end,
                        set = function(info, value) db.MicroX = value end
                    },
					MicroY = {
                        order = 4,
                        name = "MicroMenu Up and Down",
                        desc = "Set the Top and Bottom point of the MicroMenu if enabled",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.MicroY end,
                        set = function(info, value) db.MicroY = value end
                    },
					
					MicroScale = {
                        order = 64,
                        name = "Micro Scale",
                        desc = "Change the scale",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 0.25,
						max = 4,
						step  = 0.01,
						bigStep = 0.01,
						isPercent = false,
                        get = function() return db.MicroScale end,
                        set = function(info, value) db.MicroScale = value end
                    },
                }
            },
			BagBar = {
                order = 70,
                name = "Bag Bar",
                type = "group",
                args = {
				ReloadReminder = {
                        order = 1,
                        name = "Remember to Reload the UI (/rl) after adjusting the settings",
						fontSize  = "large",
                        desc = "Remember to Reload",
                        descStyle = "inline",
                        type = "description",
                        width = "full",
                       
                    },
                     BagDisable = {
                        order = 2,
                        name = "Disable",
                        desc = "Disable the Bags",
                        descStyle = "inline",
                        type = "toggle",
                        width = "double",
                        get = function() return db.BagDisable end,
                        set = function(info, value) db.BagDisable = value end
                     },
					 BagsX = {
                        order = 3,
                        name = "Bags Left and Right",
                        desc = "Set the Left and Right point of the Bags if enabled",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.BagsX end,
                        set = function(info, value) db.BagsX = value end
                    },
					BagsY = {
                        order = 4,
                        name = "Bags Up and Down",
                        desc = "Set the Top and Bottom point of the Bags if enabled",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.BagsY end,
                        set = function(info, value) db.BagsY = value end
                    },

					BagsScale = {
                        order = 74,
                        name = "Bag Scale",
                        desc = "Change the scale",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 0.25,
						max = 4,
						step  = 0.01,
						bigStep = 0.01,
						isPercent = false,
                        get = function() return db.BagsScale end,
                        set = function(info, value) db.BagsScale = value end
                    },
					OnlyMainBag = {
                        order = 75,
                        name = "MainBag",
                        desc = "Show only the Backpack",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.OnlyMainBag end,
                        set = function(info, value) db.OnlyMainBag = value end
                     },
					 BagsBlackBorder = {
                        order = 76,
                        name = "Black Border",
                        desc = "use Black border color",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.BagsBlackBorder end,
                        set = function(info, value) db.BagsBlackBorder = value end
                     },
					 BagsNoBorder = {
                        order = 76,
                        name = "No Border",
                        desc = "use no border color",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.BagsNoBorder end,
                        set = function(info, value) db.BagsNoBorder = value end
                     },
					 BagsBorderSize = {
                        order = 77,
                        name = "Bags Border Size",
                        desc = "Change the Border Size",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 0,
						max = 50,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.BagsBorderSize end,
                        set = function(info, value) db.BagsBorderSize = value end
                    },
					BagsBorderPadding = {
                        order = 78,
                        name = "Bags Border Padding",
                        desc = "Change the Padding",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -10,
						max = 50,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.BagsBorderPadding end,
                        set = function(info, value) db.BagsBorderPadding = value end
                    },
                }
            },
			-- ActionBars = {
                -- order = 80,
                -- name = "Action Bars",
                -- type = "group",
                -- args = {	
				-- ReloadReminder = {
                        -- order = 1,
                        -- name = "Remember to Reload the UI (/rl) after adjusting the settings",
						-- fontSize  = "large",
                        -- desc = "Remember to Reload",
                        -- descStyle = "inline",
                        -- type = "description",
                        -- width = "full",
                       
                    -- },
					-- ABDisable = {
                        -- order = 2,
                        -- name = "Disable All Action Bars",
                        -- desc = "Disable ALL the Action Bars",
                        -- descStyle = "inline",
                        -- type = "toggle",
                        -- width = "double",
                        -- get = function() return db.ABDisable end,
                        -- set = function(info, value) db.ABDisable = value end
                     -- },		
					-- AB1X = {
                        -- order = 3,
                        -- name = "Action Bar 1 Set Left and Right",
                        -- desc = "Set the Left and Right point of the Action Bar 1  Set if enabled",
                        -- descStyle = "inline",
                        -- type = "range",
                        -- width = "double",
						-- min = -2500,
						-- max = 2500,
						-- step  = 1,
						-- bigStep = 5,
						-- isPercent = false,
                        -- get = function() return db.AB1X end,
                        -- set = function(info, value) db.AB1X = value end
                    -- },
					-- AB1Y = {
                        -- order = 4,
                        -- name = "Action Bar 1  Set Up and Down",
                        -- desc = "Set the Top and Bottom point of the Action Bar 1  Set if enabled",
                        -- descStyle = "inline",
                        -- type = "range",
                        -- width = "double",
						-- min = -2500,
						-- max = 2500,
						-- step  = 1,
						-- bigStep = 5,
						-- isPercent = false,
                        -- get = function() return db.AB1Y end,
                        -- set = function(info, value) db.AB1Y = value end
                    -- },		
					-- AB1Layout = {
					-- order = 5,
						-- type = 'select',
						-- name = 'Action Bar 1 Layout',
						-- desc = 'Action Bar 1 Layout',
						 -- values = {"1x12","2x6","3x4","12x1","6x2","4x3"},
						  -- get = function()
							  -- return db.AB1Layout
						 -- end,
						 -- set = function(self,key)
							  -- db.AB1Layout = key
						 -- end,
					-- },					
					-- AB1ButtonSize = {
                        -- order = 6,
                        -- name = "Action Bar 1 Button Size",
                        -- desc = "Set the Size of the buttons",
                        -- descStyle = "inline",
                        -- type = "range",
                        -- width = "double",
						-- min = 10,
						-- max = 60,
						-- step  = 1,
						-- bigStep = 1,
						-- isPercent = false,
                        -- get = function() return db.AB1ButtonSize end,
                        -- set = function(info, value) db.AB1ButtonSize = value end
                    -- },
					-- AB1ButtonSpacing = {
                        -- order = 7,
                        -- name = "Action Bar 1 Button Spacing",
                        -- desc = "Set the Spacing of the buttons",
                        -- descStyle = "inline",
                        -- type = "range",
                        -- width = "double",
						-- min = -5,
						-- max = 20,
						-- step  = 1,
						-- bigStep = 1,
						-- isPercent = false,
                        -- get = function() return db.AB1ButtonSpacing end,
                        -- set = function(info, value) db.AB1ButtonSpacing = value end
                    -- },
					-- AB2X = {
                        -- order = 8,
                        -- name = "Action Bar 2 Set Left and Right",
                        -- desc = "Set the Left and Right point of the Action Bar 2  Set if enabled",
                        -- descStyle = "inline",
                        -- type = "range",
                        -- width = "double",
						-- min = -2500,
						-- max = 2500,
						-- step  = 1,
						-- bigStep = 5,
						-- isPercent = false,
                        -- get = function() return db.AB2X end,
                        -- set = function(info, value) db.AB2X = value end
                    -- },
					-- AB2Y = {
                        -- order = 9,
                        -- name = "Action Bar 2  Set Up and Down",
                        -- desc = "Set the Top and Bottom point of the Action Bar 2  Set if enabled",
                        -- descStyle = "inline",
                        -- type = "range",
                        -- width = "double",
						-- min = -2500,
						-- max = 2500,
						-- step  = 1,
						-- bigStep = 5,
						-- isPercent = false,
                        -- get = function() return db.AB2Y end,
                        -- set = function(info, value) db.AB2Y = value end
                    -- },		
					-- AB2Layout = {
					-- order = 10,
						-- type = 'select',
						-- name = 'Action Bar 2 Layout',
						-- desc = 'Action Bar 2 Layout',
						 -- values = {"1x12","2x6","3x4","12x1","6x2","4x3"},
						  -- get = function()
							  -- return db.AB2Layout
						 -- end,
						 -- set = function(self,key)
							  -- db.AB2Layout = key
						 -- end,
					-- },
					-- AB2ButtonSize = {
                        -- order = 11,
                        -- name = "Action Bar 2 Button Size",
                        -- desc = "Set the Size of the buttons",
                        -- descStyle = "inline",
                        -- type = "range",
                        -- width = "double",
						-- min = 10,
						-- max = 60,
						-- step  = 1,
						-- bigStep = 1,
						-- isPercent = false,
                        -- get = function() return db.AB2ButtonSize end,
                        -- set = function(info, value) db.AB2ButtonSize = value end
                    -- },
					-- AB2ButtonSpacing = {
                        -- order = 12,
                        -- name = "Action Bar 2 Button Spacing",
                        -- desc = "Set the Spacing of the buttons",
                        -- descStyle = "inline",
                        -- type = "range",
                        -- width = "double",
						-- min = -5,
						-- max = 20,
						-- step  = 1,
						-- bigStep = 1,
						-- isPercent = false,
                        -- get = function() return db.AB2ButtonSpacing end,
                        -- set = function(info, value) db.AB2ButtonSpacing = value end
                    -- },
					-- AB3X = {
                        -- order = 13,
                        -- name = "Action Bar 3 Set Left and Right",
                        -- desc = "Set the Left and Right point of the Action Bar 3 Set if enabled",
                        -- descStyle = "inline",
                        -- type = "range",
                        -- width = "double",
						-- min = -2500,
						-- max = 2500,
						-- step  = 1,
						-- bigStep = 5,
						-- isPercent = false,
                        -- get = function() return db.AB3X end,
                        -- set = function(info, value) db.AB3X = value end
                    -- },
					-- AB3Y = {
                        -- order = 14,
                        -- name = "Action Bar 3  Set Up and Down",
                        -- desc = "Set the Top and Bottom point of the Action Bar 3  Set if enabled",
                        -- descStyle = "inline",
                        -- type = "range",
                        -- width = "double",
						-- min = -2500,
						-- max = 2500,
						-- step  = 1,
						-- bigStep = 5,
						-- isPercent = false,
                        -- get = function() return db.AB3Y end,
                        -- set = function(info, value) db.AB3Y = value end
                    -- },		
					-- AB3Layout = {
					-- order = 15,
						-- type = 'select',
						-- name = 'Action Bar 3 Layout',
						-- desc = 'Action Bar 3 Layout',
						 -- values = {"1x12","2x6","3x4","12x1","6x2","4x3"},
						  -- get = function()
							  -- return db.AB3Layout
						 -- end,
						 -- set = function(self,key)
							  -- db.AB3Layout = key
						 -- end,
					-- },
					-- AB3ButtonSize = {
                        -- order = 16,
                        -- name = "Action Bar 3 Button Size",
                        -- desc = "Set the Size of the buttons",
                        -- descStyle = "inline",
                        -- type = "range",
                        -- width = "double",
						-- min = 10,
						-- max = 60,
						-- step  = 1,
						-- bigStep = 1,
						-- isPercent = false,
                        -- get = function() return db.AB3ButtonSize end,
                        -- set = function(info, value) db.AB3ButtonSize = value end
                    -- },
					-- AB3ButtonSpacing = {
                        -- order = 17,
                        -- name = "Action Bar 3 Button Spacing",
                        -- desc = "Set the Spacing of the buttons",
                        -- descStyle = "inline",
                        -- type = "range",
                        -- width = "double",
						-- min = -5,
						-- max = 20,
						-- step  = 1,
						-- bigStep = 1,
						-- isPercent = false,
                        -- get = function() return db.AB3ButtonSpacing end,
                        -- set = function(info, value) db.AB3ButtonSpacing = value end
                    -- },
					-- AB4X = {
                        -- order = 18,
                        -- name = "Action Bar 4 Set Left and Right",
                        -- desc = "Set the Left and Right point of the Action Bar 4 Set if enabled",
                        -- descStyle = "inline",
                        -- type = "range",
                        -- width = "double",
						-- min = -2500,
						-- max = 2500,
						-- step  = 1,
						-- bigStep = 5,
						-- isPercent = false,
                        -- get = function() return db.AB4X end,
                        -- set = function(info, value) db.AB4X = value end
                    -- },
					-- AB4Y = {
                        -- order = 19,
                        -- name = "Action Bar 4  Set Up and Down",
                        -- desc = "Set the Top and Bottom point of the Action Bar 4  Set if enabled",
                        -- descStyle = "inline",
                        -- type = "range",
                        -- width = "double",
						-- min = -2500,
						-- max = 2500,
						-- step  = 1,
						-- bigStep = 5,
						-- isPercent = false,
                        -- get = function() return db.AB4Y end,
                        -- set = function(info, value) db.AB4Y = value end
                    -- },		
					-- AB4Layout = {
					-- order = 20,
						-- type = 'select',
						-- name = 'Action Bar 4 Layout',
						-- desc = 'Action Bar 4 Layout',
						 -- values = {"1x12","2x6","3x4","12x1","6x2","4x3"},
						  -- get = function()
							  -- return db.AB4Layout
						 -- end,
						 -- set = function(self,key)
							  -- db.AB4Layout = key
						 -- end,
					-- },
					-- AB4ButtonSize = {
                        -- order = 21,
                        -- name = "Action Bar 4 Button Size",
                        -- desc = "Set the Size of the buttons",
                        -- descStyle = "inline",
                        -- type = "range",
                        -- width = "double",
						-- min = 10,
						-- max = 60,
						-- step  = 1,
						-- bigStep = 1,
						-- isPercent = false,
                        -- get = function() return db.AB4ButtonSize end,
                        -- set = function(info, value) db.AB4ButtonSize = value end
                    -- },
					-- AB4ButtonSpacing = {
                        -- order = 22,
                        -- name = "Action Bar 4 Button Spacing",
                        -- desc = "Set the Spacing of the buttons",
                        -- descStyle = "inline",
                        -- type = "range",
                        -- width = "double",
						-- min = -5,
						-- max = 20,
						-- step  = 1,
						-- bigStep = 1,
						-- isPercent = false,
                        -- get = function() return db.AB4ButtonSpacing end,
                        -- set = function(info, value) db.AB4ButtonSpacing = value end
                    -- },
					-- AB5X = {
                        -- order = 23,
                        -- name = "Action Bar 5 Set Left and Right",
                        -- desc = "Set the Left and Right point of the Action Bar 5 Set if enabled",
                        -- descStyle = "inline",
                        -- type = "range",
                        -- width = "double",
						-- min = -2500,
						-- max = 2500,
						-- step  = 1,
						-- bigStep = 5,
						-- isPercent = false,
                        -- get = function() return db.AB5X end,
                        -- set = function(info, value) db.AB5X = value end
                    -- },
					-- AB5Y = {
                        -- order = 24,
                        -- name = "Action Bar 5  Set Up and Down",
                        -- desc = "Set the Top and Bottom point of the Action Bar 5  Set if enabled",
                        -- descStyle = "inline",
                        -- type = "range",
                        -- width = "double",
						-- min = -2500,
						-- max = 2500,
						-- step  = 1,
						-- bigStep = 5,
						-- isPercent = false,
                        -- get = function() return db.AB5Y end,
                        -- set = function(info, value) db.AB5Y = value end
                    -- },		
					-- AB5Layout = {
					-- order = 25,
						-- type = 'select',
						-- name = 'Action Bar 5 Layout',
						-- desc = 'Action Bar 5 Layout',
						 -- values = {"1x12","2x6","3x4","12x1","6x2","4x3"},
						  -- get = function()
							  -- return db.AB5Layout
						 -- end,
						 -- set = function(self,key)
							  -- db.AB5Layout = key
						 -- end,
					-- },
					-- AB5ButtonSize = {
                        -- order = 26,
                        -- name = "Action Bar 5 Button Size",
                        -- desc = "Set the Size of the buttons",
                        -- descStyle = "inline",
                        -- type = "range",
                        -- width = "double",
						-- min = 10,
						-- max = 60,
						-- step  = 1,
						-- bigStep = 1,
						-- isPercent = false,
                        -- get = function() return db.AB5ButtonSize end,
                        -- set = function(info, value) db.AB5ButtonSize = value end
                    -- },
					-- AB5ButtonSpacing = {
                        -- order = 27,
                        -- name = "Action Bar 5 Button Spacing",
                        -- desc = "Set the Spacing of the buttons",
                        -- descStyle = "inline",
                        -- type = "range",
                        -- width = "double",
						-- min = -5,
						-- max = 20,
						-- step  = 1,
						-- bigStep = 1,
						-- isPercent = false,
                        -- get = function() return db.AB5ButtonSpacing end,
                        -- set = function(info, value) db.AB5ButtonSpacing = value end
                    -- },
					-- PetBarX = {
                        -- order = 28,
                        -- name = "Pet Bar Set Left and Right",
                        -- desc = "Set the Left and Right point of the Pet Bar Set if enabled",
                        -- descStyle = "inline",
                        -- type = "range",
                        -- width = "double",
						-- min = -2500,
						-- max = 2500,
						-- step  = 1,
						-- bigStep = 5,
						-- isPercent = false,
                        -- get = function() return db.PetBarX end,
                        -- set = function(info, value) db.PetBarX = value end
                    -- },
					-- PetBarY = {
                        -- order = 29,
                        -- name = "Pet Bar Set Up and Down",
                        -- desc = "Set the Top and Bottom point of the Pet Bar Set if enabled",
                        -- descStyle = "inline",
                        -- type = "range",
                        -- width = "double",
						-- min = -2500,
						-- max = 2500,
						-- step  = 1,
						-- bigStep = 5,
						-- isPercent = false,
                        -- get = function() return db.PetBarY end,
                        -- set = function(info, value) db.PetBarY = value end
                    -- },
					-- ABPetButtonSize = {
                        -- order = 30,
                        -- name = "Pet Bar Button Size",
                        -- desc = "Set the Size of the buttons",
                        -- descStyle = "inline",
                        -- type = "range",
                        -- width = "double",
						-- min = 10,
						-- max = 60,
						-- step  = 1,
						-- bigStep = 1,
						-- isPercent = false,
                        -- get = function() return db.ABPetButtonSize end,
                        -- set = function(info, value) db.ABPetButtonSize = value end
                    -- },
					-- ABPetButtonSpacing = {
                        -- order = 31,
                        -- name = "Pet Bar Button Spacing",
                        -- desc = "Set the Spacing of the buttons",
                        -- descStyle = "inline",
                        -- type = "range",
                        -- width = "double",
						-- min = -5,
						-- max = 20,
						-- step  = 1,
						-- bigStep = 1,
						-- isPercent = false,
                        -- get = function() return db.ABPetButtonSpacing end,
                        -- set = function(info, value) db.ABPetButtonSpacing = value end
                    -- },
					-- StanceX = {
                        -- order = 32,
                        -- name = "Stance Set Left and Right",
                        -- desc = "Set the Left and Right point of the Stance Set if enabled",
                        -- descStyle = "inline",
                        -- type = "range",
                        -- width = "double",
						-- min = -2500,
						-- max = 2500,
						-- step  = 1,
						-- bigStep = 5,
						-- isPercent = false,
                        -- get = function() return db.StanceX end,
                        -- set = function(info, value) db.StanceX = value end
                    -- },
					-- StanceY = {
                        -- order = 33,
                        -- name = "Stance Set Up and Down",
                        -- desc = "Set the Top and Bottom point of the Stance Set if enabled",
                        -- descStyle = "inline",
                        -- type = "range",
                        -- width = "double",
						-- min = -2500,
						-- max = 2500,
						-- step  = 1,
						-- bigStep = 5,
						-- isPercent = false,
                        -- get = function() return db.StanceY end,
                        -- set = function(info, value) db.StanceY = value end
                    -- },
					-- ABStanceButtonSize = {
                        -- order = 34,
                        -- name = "StanceBar Button Size",
                        -- desc = "Set the Size of the buttons",
                        -- descStyle = "inline",
                        -- type = "range",
                        -- width = "double",
						-- min = 10,
						-- max = 60,
						-- step  = 1,
						-- bigStep = 1,
						-- isPercent = false,
                        -- get = function() return db.ABStanceButtonSize end,
                        -- set = function(info, value) db.ABStanceButtonSize = value end
                    -- },
					-- ABStanceButtonSpacing = {
                        -- order = 35,
                        -- name = "Stance Bar Button Spacing",
                        -- desc = "Set the Spacing of the buttons",
                        -- descStyle = "inline",
                        -- type = "range",
                        -- width = "double",
						-- min = -5,
						-- max = 20,
						-- step  = 1,
						-- bigStep = 1,
						-- isPercent = false,
                        -- get = function() return db.ABStanceButtonSpacing end,
                        -- set = function(info, value) db.ABStanceButtonSpacing = value end
                    -- },
					-- ABBlackBorder = {
                        -- order = 36,
                        -- name = "Black Border",
                        -- desc = "use Black border color",
                        -- descStyle = "inline",
                        -- type = "toggle",
                        -- width = "single",
                        -- get = function() return db.ABBlackBorder end,
                        -- set = function(info, value) db.ABBlackBorder = value end
                     -- },
					 -- ABNoBorder = {
                        -- order = 37,
                        -- name = "No Border",
                        -- desc = "use no border color",
                        -- descStyle = "inline",
                        -- type = "toggle",
                        -- width = "single",
                        -- get = function() return db.ABNoBorder end,
                        -- set = function(info, value) db.ABNoBorder = value end
                     -- },
					 -- ABBorderSize = {
                        -- order = 38,
                        -- name = "Border Size",
                        -- desc = "Change the Action Bar  Border Size",
                        -- descStyle = "inline",
                        -- type = "range",
                        -- width = "double",
						-- min = 0,
						-- max = 50,
						-- step  = 1,
						-- bigStep = 1,
						-- isPercent = false,
                        -- get = function() return db.ABBorderSize end,
                        -- set = function(info, value) db.ABBorderSize = value end
                    -- },
					-- ABBorderPadding = {
                        -- order = 39,
                        -- name = "Border Padding",
                        -- desc = "Change the Action Bar  Border Padding",
                        -- descStyle = "inline",
                        -- type = "range",
                        -- width = "double",
						-- min = -10,
						-- max = 50,
						-- step  = 1,
						-- bigStep = 1,
						-- isPercent = false,
                        -- get = function() return db.ABBorderPadding end,
                        -- set = function(info, value) db.ABBorderPadding = value end
                    -- },
					
					
                -- }
            -- },
			MiniMap = {
                order = 90,
                name = "Mini Map",
                type = "group",
                args = {
				ReloadReminder = {
                        order = 1,
                        name = "Remember to Reload the UI (/rl) after adjusting the settings",
						fontSize  = "large",
                        desc = "Remember to Reload",
                        descStyle = "inline",
                        type = "description",
                        width = "full",
                       
                    },
                     MMDisable = {
                        order = 2,
                        name = "Disable",
                        desc = "Disable the Mini Map",
                        descStyle = "inline",
                        type = "toggle",
                        width = "double",
                        get = function() return db.MMDisable end,
                        set = function(info, value) db.MMDisable = value end
                     },
					  MiniMapX = {
                        order = 3,
                        name = "MiniMap Left and Right",
                        desc = "Set the Left and Right point of the MiniMap if enabled",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.MiniMapX end,
                        set = function(info, value) db.MiniMapX = value end
                    },
					MiniMapY = {
                        order = 4,
                        name = "MiniMap Up and Down",
                        desc = "Set the Top and Bottom point of the MiniMap if enabled",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.MiniMapY end,
                        set = function(info, value) db.MiniMapY = value end
                    },
				
					 MiniMapHeight = {
                        order = 94,
                        name = "Mini Map Height",
                        desc = "Change the keight of the Mini Map",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 50,
						max = 450,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.MiniMapHeight end,
                        set = function(info, value) db.MiniMapHeight = value end
                    },
					MiniMapWidth = {
                        order = 95,
                        name = "Mini Map Width",
                        desc = "Change the Width of the Mini Map",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 50,
						max = 450,
						softMin = 50,
						softMax  = 450,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.MiniMapWidth end,
                        set = function(info, value) db.MiniMapWidth = value end
                    },
					Zonefont = {
				    order = 96,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Zone Text Font',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.ZonefontFontKey -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.ZonefontFontKey = key -- saves our new selection the the current one
						 end,
					},
					ZoneFontOutline = {
					order = 97,
						type = 'select',
						name = 'Zone Font Outline',
						desc = 'Zone Font Outlines for the fonts',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.ZoneFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)					
							  db.ZoneFontOutline = key -- saves our new selection the the current one					
						 end,
					},
					ZoneFontSize = {
                        order = 98,
                        name = "Zone Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 6,
						max = 100,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.ZoneFontSize end,
                        set = function(info, value) db.ZoneFontSize = value end
                    },
					ZoneTextY = {
                        order = 99,
                        name = "Text UP&DOWN!",
                        desc = "Bump the ZONE text UP and DOWN!!!!",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -20,
						max = 20,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.ZoneTextY end,
                        set = function(info, value) db.ZoneTextY = value end
                    },
					Timefont = {
				    order = 100,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Time Text Font',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.TimefontFontKey -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.TimefontFontKey = key -- saves our new selection the the current one
						 end,
					},
					TimeFontOutline = {
					order = 101,
						type = 'select',
						name = 'Time Font Outline',
						desc = 'Time Font Outlines for the fonts',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.TimeFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							
							  db.TimeFontOutline = key -- saves our new selection the the current one
						
						 end,
					},
					TimeFontSize = {
                        order = 102,
                        name = "Time Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 6,
						max = 100,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.TimeFontSize end,
                        set = function(info, value) db.TimeFontSize = value end
                    },
					
					TimeY = {
                        order = 103,
                        name = "Time Text UP&DOWN!",
                        desc = "Move the Time Text Up and Down",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -100,
						max = 100,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.TimeY end,
                        set = function(info, value) db.TimeY = value end
                    },

					 MMBlackBorder = {
                        order = 104,
                        name = "Black Border",
                        desc = "use Black border color",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.MMBlackBorder end,
                        set = function(info, value) db.MMBlackBorder = value end
                     },
					 MMNoBorder = {
                        order = 105,
                        name = "No Border",
                        desc = "use no border color",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.MMNoBorder end,
                        set = function(info, value) db.MMNoBorder = value end
                     },
					 MMBorderSize = {
                        order = 106,
                        name = "Mini Map Border Size",
                        desc = "Change the Mini Map Border Size",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 0,
						max = 50,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.MMBorderSize end,
                        set = function(info, value) db.MMBorderSize = value end
                    },
					MMBorderPadding = {
                        order = 107,
                        name = "Border Padding",
                        desc = "Change the Mini Map Border Padding",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -10,
						max = 50,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.MMBorderPadding end,
                        set = function(info, value) db.MMBorderPadding = value end
                    },
                }
            },
			PsychoPlates = {
                order = 110,
                name = "NamePlates",
                type = "group",
                args = {
				ReloadReminder = {
                        order = 1,
                        name = "Remember to Reload the UI (/rl) after adjusting the settings",
						fontSize  = "large",
                        desc = "Remember to Reload",
                        descStyle = "inline",
                        type = "description",
                        width = "full",
                       
                    },
                     DisablePlates = {
                        order = 111,
                        name = "Disable the Nameplates",
                        desc = "Turns off the Name Plates",
                        descStyle = "inline",
                        type = "toggle",
                        width = "double",
                        get = function() return db.DisablePlates end,
                        set = function(info, value) db.DisablePlates = value end
                     },
					 NPStatusBar = {
						order = 112,
						type = 'select',
						 dialogControl = 'LSM30_Statusbar', 
						 name = 'Nameplate Status Bars',
						 desc = 'Fonts for peeps who like to change Status Bars',
						 values = LSM:HashTable("statusbar"),	 
						  get = function()
							  return db.NPStatusBar -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.NPStatusBar = key -- saves our new selection the the current one
						 end,
					},
					 NPFont = {
				    order = 113,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Font',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.NPFontKey -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.NPFontKey = key -- saves our new selection the the current one
						 end,
					},
					NPFontOutline = {
					order = 114,
						type = 'select',
						 name = 'Font Outline',
						 desc = 'outline',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.NPFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							
							  db.NPFontOutline = key -- saves our new selection the the current one
						
						 end,
					},
					NPFontSize = {
                        order = 115,
                        name = "Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 15,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.NPFontSize end,
                        set = function(info, value) db.NPFontSize = value end
                    },
					 NPLevelFont = {
				    order = 116,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Level Font',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.NPLevelFont 
						 end,
						 set = function(self,key)
							  db.NPLevelFont = key 
						 end,
					},
					NPLevelFontOutline = {
					order = 117,
						type = 'select',
						 name = 'Level font outline',
						 desc = 'Level font outline',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.NPLevelFontOutline 
						 end,
						 set = function(self,key)
							
							  db.NPLevelFontOutline = key 
						
						 end,
					},
					NPLevelFontSize = {
                        order = 118,
                        name = "Level Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 15,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.NPLevelFontSize end,
                        set = function(info, value) db.NPLevelFontSize = value end
                    },
					NPHealthFont = {
				    order = 119,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Health Font',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.NPHealthFont 
						 end,
						 set = function(self,key)
							  db.NPHealthFont = key 
						 end,
					},
					NPHealthFontOutline = {
					order = 120,
						type = 'select',
						 name = 'Health font outline',
						 desc = 'Health font outline',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.NPHealthFontOutline 
						 end,
						 set = function(self,key)	
							  db.NPHealthFontOutline = key 
						 end,
					},
					
					NPHealthFontSize = {
                        order = 121,
                        name = "Health Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 15,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.NPHealthFontSize end,
                        set = function(info, value) db.NPHealthFontSize = value end
                    },
					ShowName = {
                        order = 126,
                        name = "Show Name",
                        desc = "Turns off the Name Plates Name text",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.ShowName end,
                        set = function(info, value) db.ShowName = value end
                     },
					 ShowLevel = {
                        order = 127,
                        name = "Show Level",
                        desc = "Turns off the Name Plates Level text",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.ShowLevel end,
                        set = function(info, value) db.ShowLevel = value end
                     },
					  ShowElite = {
                        order = 128,
                        name = "Show Elite",
                        desc = "Turns off the Name Plates Elite text",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.ShowElite end,
                        set = function(info, value) db.ShowElite = value end
                     },
					  ShowFloatingCombatText = {
                        order = 129,
                        name = "Floating Combat Text",
                        desc = "Turns off the Floating Combattext",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.ShowFloatingCombatText end,
                        set = function(info, value) db.ShowFloatingCombatText = value end
                     },
					  NPBlackBorder = {
                        order = 130,
                        name = "Black Border",
                        desc = "use Black border color",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.NPBlackBorder end,
                        set = function(info, value) db.NPBlackBorder = value end
                     },
					 NPNoBorder = {
                        order = 131,
                        name = "No Border",
                        desc = "use no border color",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.NPNoBorder end,
                        set = function(info, value) db.NPNoBorder = value end
                     },
					 NPBorderSize = {
                        order = 132,
                        name = "Border Size",
                        desc = "Change the Nameplate Border Size",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 0,
						max = 50,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.NPBorderSize end,
                        set = function(info, value) db.NPBorderSize = value end
                    },
					NPBorderPadding = {
                        order =133,
                        name = "Border Padding",
                        desc = "Change the Nameplate Border Padding",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -10,
						max = 50,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.NPBorderPadding end,
                        set = function(info, value) db.NPBorderPadding = value end
                    },
					NPDisableAuras = {
                        order = 134,
                        name = "Disable Auras",
                        desc = "Disable the Buffs/Debuffs/Auras",
                        descStyle = "inline",
                        type = "toggle",
                        width = "double",
                        get = function() return db.NPDisableAuras end,
                        set = function(info, value) db.NPDisableAuras = value end
                     },

                }
            },
			PlayerFrame = {
                order = 200,
                name = "Player Frame",
                type = "group",
                args = {
				ReloadReminder = {
                        order = 1,
                        name = "Remember to Reload the UI (/rl) after adjusting the settings",
						fontSize  = "large",
                        desc = "Remember to Reload",
                        descStyle = "inline",
                        type = "description",
                        width = "full",
                    },
                     PFDisable = {
                        order = 2,
                        name = "Disable",
                        desc = "Disable the Player Frame",                       
                        type = "toggle",
                        width = "single",
                        get = function() return db.PFDisable end,
                        set = function(info, value) db.PFDisable = value end
                     },
					 PlayerX = {
                        order = 3,
                        name = "Player Frame Left and Right",
                        desc = "Set the Left and Right point of the Player Frame if enabled",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.PlayerX end,
                        set = function(info, value) db.PlayerX = value end
                    },
					PlayerY = {
                        order = 4,
                        name = "Player Frame Up and Down",
                        desc = "Set the Top and Bottom point of the Player Frame if enabled",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.PlayerY end,
                        set = function(info, value) db.PlayerY = value end
                    },
					 PFDisableCB = {
                        order = 5,
                        name = "Disable Cast Bar",
                        desc = "Disable the Player Frame Cast Bar",                       
                        type = "toggle",
                        width = "single",
                        get = function() return db.PFDisableCB end,
                        set = function(info, value) db.PFDisableCB = value end
                     },
					 PFScale = {
                        order = 6,
                        name = "Scale",
                        desc = "Overall scale of the Player Frame",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 0.25,
						max = 4.5,
						step  = 0.05,
						bigStep = 0.05,
						isPercent = false,
                        get = function() return db.PFScale end,
                        set = function(info, value) db.PFScale = value end
                    },
					  PFBlackBorder = {
                        order = 7,
                        name = "Black Border",
                        desc = "use Black border color",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.PFBlackBorder end,
                        set = function(info, value) db.PFBlackBorder = value end
                     },
					 PFNoBorder = {
                        order = 8,
                        name = "No Border",
                        desc = "use no border color",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.PFNoBorder end,
                        set = function(info, value) db.PFNoBorder = value end
                     },
					 PFBorderSize = {
                        order = 9,
                        name = "Border Size",
                        desc = "Change the Player Frame Border Size",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 0,
						max = 50,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.PFBorderSize end,
                        set = function(info, value) db.PFBorderSize = value end
                    },
					PFBorderPadding = {
                        order = 10,
                        name = "Border Padding",
                        desc = "Change the Player Frame Border Padding",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -10,
						max = 50,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.PFBorderPadding end,
                        set = function(info, value) db.PFBorderPadding = value end
                    },
					PFStatusBarHealth = {
						order = 11,
						type = 'select',
						 dialogControl = 'LSM30_Statusbar', 
						 name = 'Health Status Bars',
						 desc = 'Status Bars for peeps who like to change Status Bars',
						 values = LSM:HashTable("statusbar"),	 
						  get = function()
							  return db.PFStatusBarHealth -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.PFStatusBarHealth = key -- saves our new selection the the current one
						 end,
					},
					PFStatusBarPower = {
						order = 12,
						type = 'select',
						 dialogControl = 'LSM30_Statusbar', 
						 name = 'Power Status Bar',
						 desc = 'Status Bars  for peeps who like to change Status Bars',
						 values = LSM:HashTable("statusbar"),	 
						  get = function()
							  return db.PFStatusBarPower -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.PFStatusBarPower = key -- saves our new selection the the current one
						 end,
					},
					PFStatusBarCB = {
						order = 13,
						type = 'select',
						 dialogControl = 'LSM30_Statusbar', 
						 name = 'Cast Bar Status Bar',
						 desc = 'Status Bars  for peeps who like to change Status Bars',
						 values = LSM:HashTable("statusbar"),	 
						  get = function()
							  return db.PFStatusBarCB -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.PFStatusBarCB = key -- saves our new selection the the current one
						 end,
					},
					PFStatusBarClassPower = {
						order = 14,
						type = 'select',
						 dialogControl = 'LSM30_Statusbar', 
						 name = 'Class Power Status Bar',
						 desc = 'Status Bars  for peeps who like to change Status Bars',
						 values = LSM:HashTable("statusbar"),	 
						  get = function()
							  return db.PFStatusBarClassPower -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.PFStatusBarClassPower = key -- saves our new selection the the current one
						 end,
					},
					PFStatusBarAltPower = {
						order = 15,
						type = 'select',
						 dialogControl = 'LSM30_Statusbar', 
						 name = 'Alt Power Status Bar',
						 desc = 'Status Bars  for peeps who like to change Status Bars',
						 values = LSM:HashTable("statusbar"),	 
						  get = function()
							  return db.PFStatusBarAltPower -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.PFStatusBarAltPower = key -- saves our new selection the the current one
						 end,
					},
					 PFDisableAuras = {
                        order = 202,
                        name = "Disable Auras",
                        desc = "Disable the Player Buffs/Debuffs/Auras",
                        type = "toggle",
                        width = "single",
                        get = function() return db.PFDisableAuras end,
                        set = function(info, value) db.PFDisableAuras = value end
                     },
					 PFDisableHealthPercent = {
                        order = 203,
                        name = "Disable Health Percent",
                        desc = "Disable the Health Percent text",
                        type = "toggle",
                        width = "single",
                        get = function() return db.PFDisableHealthPercent end,
                        set = function(info, value) db.PFDisableHealthPercent = value end
                     },
					 PFDisableHealth = {
                        order = 204,
                        name = "Disable Health Text",
                        desc = "Disable the Health text",
                        type = "toggle",
                        width = "single",
                        get = function() return db.PFDisableHealth end,
                        set = function(info, value) db.PFDisableHealth = value end
                     },
					 HealthFont = {
						order = 205,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Health Font',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.HealthFont -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.HealthFont = key -- saves our new selection the the current one
						 end,
					},
					HealthFontOutline = {
						order = 206,
						type = 'select',
						 name = 'Health font outline',
						 desc = 'Health font outline',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.HealthFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							
							  db.HealthFontOutline = key -- saves our new selection the the current one
						
						 end,
					},
					HealthFontSize = {
                        order = 207,
                        name = "Health Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 25,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.HealthFontSize end,
                        set = function(info, value) db.HealthFontSize = value end
                    },
					PFDisableManaPercent = {
                        order = 208,
                        name = "Disable Power Percent",
                        desc = "Disable the Power Percent text",
                        type = "toggle",
                        width = "single",
                        get = function() return db.PFDisableManaPercent end,
                        set = function(info, value) db.PFDisableManaPercent = value end
                     },
					 PFDisableMana = {
                        order = 209,
                        name = "Disable Power Text",
                        desc = "Disable the Power text",
                        type = "toggle",
                        width = "single",
                        get = function() return db.PFDisableMana end,
                        set = function(info, value) db.PFDisableMana = value end
                     },
					 ManaFont = {
						order = 210,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Power Font',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.ManaFont -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.ManaFont = key -- saves our new selection the the current one
						 end,
					},
					ManaFontOutline = {
						order = 211,
						type = 'select',
						 name = 'Power font outline',
						 desc = 'Power font outline',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.ManaFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							
							  db.ManaFontOutline = key -- saves our new selection the the current one
						
						 end,
					},
					ManaFontSize = {
                        order = 212,
                        name = "Power Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 25,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.ManaFontSize end,
                        set = function(info, value) db.ManaFontSize = value end
                    },
					PFDisableLevel = {
                        order = 213,
                        name = "Disable Level Text",
                        desc = "Disable the Level  text",
                        type = "toggle",
                        width = "single",
                        get = function() return db.PFDisableLevel end,
                        set = function(info, value) db.PFDisableLevel = value end
                     },
					 LevelFont = {
						order = 214,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Level Font',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.LevelFont -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.LevelFont = key -- saves our new selection the the current one
						 end,
					},
					LevelFontOutline = {
						order = 215,
						type = 'select',
						 name = 'Level font outline',
						 desc = 'Level font outline',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.LevelFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.LevelFontOutline = key -- saves our new selection the the current one
						 end,
					},
					LevelFontSize = {
                        order = 216,
                        name = "Level Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 25,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.LevelFontSize end,
                        set = function(info, value) db.LevelFontSize = value end
                    },
					PFDisableName = {
                        order = 217,
                        name = "Disable Name Text",
                        desc = "Disable the Name  text",
                        type = "toggle",
                        width = "single",
                        get = function() return db.PFDisableName end,
                        set = function(info, value) db.PFDisableName = value end
                     },
					 NameFont = {
						order = 218,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Name Font Name',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.NameFont -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.NameFont = key -- saves our new selection the the current one
						 end,
					},
					NameFontOutline = {
						order = 219,
						type = 'select',
						 name = 'Name font outline',
						 desc = 'Name font outline',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.NameFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.NameFontOutline = key -- saves our new selection the the current one
						 end,
					},
					NameFontSize = {
                        order = 220,
                        name = "Name Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 25,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.NameFontSize end,
                        set = function(info, value) db.NameFontSize = value end
                    },
					PlayerFloatingCombatText = {
                        order = 221,
                        name = "Floating Combat Text",
                        desc = "Turns off the Floating Combat Text",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.PlayerFloatingCombatText end,
                        set = function(info, value) db.PlayerFloatingCombatText = value end
                     },
					 PFCFNameFont = {
						order = 222,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Floating Combat Text Font',
						 desc = 'Floating Combat Text fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.PFCFNameFont -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.PFCFNameFont = key -- saves our new selection the the current one
						 end,
					},
					PFCFNameFontOutline = {
						order = 223,
						type = 'select',
						 name = 'Floating Combat Text font outline',
						 desc = 'Floating Combat Text font outline',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.PFCFNameFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.PFCFNameFontOutline = key -- saves our new selection the the current one
						 end,
					},
					PFCFNameFontSize = {
                        order = 224,
                        name = "Floating Combat Text Font Size",
                        desc = "Floating Combat Text Font Size",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 65,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.PFCFNameFontSize end,
                        set = function(info, value) db.PFCFNameFontSize = value end
                    },
					  PFDisablePortrait = {
                        order = 225,
                        name = "Disable Player Portrait",
                        desc = "Disable the Portrait",
                        type = "toggle",
                        width = "double",
                        get = function() return db.PFDisablePortrait end,
                        set = function(info, value) db.PFDisablePortrait = value end
                     },
					 PFDisablePortraitBG = {
                        order = 226,
                        name = "Disable Player Portrait Background",
                        desc = "Disable the Portrait Background",
                        type = "toggle",
                        width = "double",
                        get = function() return db.PFDisablePortraitBG end,
                        set = function(info, value) db.PFDisablePortraitBG = value end
                     },
					PortraitBGBlackOut = {
                        order = 227,
                        name = "Black Out Player Portrait Background",
                        desc = "Black the Portrait Background",
                        type = "toggle",
                        width = "double",
                        get = function() return db.PortraitBGBlackOut end,
                        set = function(info, value) db.PortraitBGBlackOut = value end
                     },
                }
            },	
			PlayerPetFrame = {
                order = 300,
                name = "Player Pet Frame",
                type = "group",
                args = {
				ReloadReminder = {
                        order = 1,
                        name = "Remember to Reload the UI (/rl) after adjusting the settings",
						fontSize  = "large",
                        desc = "Remember to Reload",
                        descStyle = "inline",
                        type = "description",
                        width = "full",
                    },
                     PFPetDisable = {
                        order = 2,
                        name = "Disable",
                        desc = "Disable the Pet Frame",                       
                        type = "toggle",
                        width = "single",
                        get = function() return db.PFPetDisable end,
                        set = function(info, value) db.PFPetDisable = value end
                     },
					  PetX = {
                        order = 3,
                        name = "Pet Frame Left and Right",
                        desc = "Set the Left and Right point of the Target Frame if enabled",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.PetX end,
                        set = function(info, value) db.PetX = value end
                    },
					PetY = {
                        order = 4,
                        name = "Pet Frame Up and Down",
                        desc = "Set the Top and Bottom point of the Target Frame if enabled",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.PetY end,
                        set = function(info, value) db.PetY = value end
                    },
					 PFPetDisableCB = {
                        order = 5,
                        name = "Disable Cast Bar",
                        desc = "Disable the Cast Bar",                       
                        type = "toggle",
                        width = "single",
                        get = function() return db.PFPetDisableCB end,
                        set = function(info, value) db.PFPetDisableCB = value end
                     },
					 PFPetScale = {
                        order = 6,
                        name = "Pet Frame Scale",
                        desc = "Overall scale of the Pet frame",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 0.25,
						max = 4.5,
						step  = 0.05,
						bigStep = 0.05,
						isPercent = false,
                        get = function() return db.PFPetScale end,
                        set = function(info, value) db.PFPetScale = value end
                    },
					  PFPetBlackBorder = {
                        order = 7,
                        name = "Black Border",
                        desc = "use Black border color",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.PFPetBlackBorder end,
                        set = function(info, value) db.PFPetBlackBorder = value end
                     },
					 PFPetNoBorder = {
                        order = 8,
                        name = "No Border",
                        desc = "use no border color",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.PFPetNoBorder end,
                        set = function(info, value) db.PFPetNoBorder = value end
                     },
					 PFPetBorderSize = {
                        order = 9,
                        name = "Pet Frame Border Size",
                        desc = "Change the  Border Size",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 0,
						max = 50,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.PFPetBorderSize end,
                        set = function(info, value) db.PFPetBorderSize = value end
                    },
					PFPetBorderPadding = {
                        order = 10,
                        name = "Pet Frame Border Padding",
                        desc = "Change the Border Padding",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -10,
						max = 50,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.PFPetBorderPadding end,
                        set = function(info, value) db.PFPetBorderPadding = value end
                    },
					PFPetStatusBarHealth = {
						order = 11,
						type = 'select',
						 dialogControl = 'LSM30_Statusbar', 
						 name = 'Pet Health Status Bars',
						 desc = 'Status Bars for peeps who like to change Status Bars',
						 values = LSM:HashTable("statusbar"),	 
						  get = function()
							  return db.PFPetStatusBarHealth -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.PFPetStatusBarHealth = key -- saves our new selection the the current one
						 end,
					},
					PFPetStatusBarPower = {
						order = 12,
						type = 'select',
						 dialogControl = 'LSM30_Statusbar', 
						 name = 'Pet Power Status Bar',
						 desc = 'Status Bars  for peeps who like to change Status Bars',
						 values = LSM:HashTable("statusbar"),	 
						  get = function()
							  return db.PFPetStatusBarPower -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.PFPetStatusBarPower = key -- saves our new selection the the current one
						 end,
					},
					PFPetStatusBarCB = {
						order = 13,
						type = 'select',
						 dialogControl = 'LSM30_Statusbar', 
						 name = 'Pet Cast Bar Status Bar',
						 desc = 'Status Bars  for peeps who like to change Status Bars',
						 values = LSM:HashTable("statusbar"),	 
						  get = function()
							  return db.PFPetStatusBarCB -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.PFPetStatusBarCB = key -- saves our new selection the the current one
						 end,
					},

					 PFPetDisableAuras = {
                        order = 202,
                        name = "Disable Auras",
                        desc = "Disable the Pet Buffs/Debuffs/Auras",
                        type = "toggle",
                        width = "single",
                        get = function() return db.PFPetDisableAuras end,
                        set = function(info, value) db.PFPetDisableAuras = value end
                     },
					 PFPetDisableHealthPercent = {
                        order = 203,
                        name = "Disable Pet Health Percent",
                        desc = "Disable the Pet Health Percent text",
                        type = "toggle",
                        width = "single",
                        get = function() return db.PFPetDisableHealthPercent end,
                        set = function(info, value) db.PFPetDisableHealthPercent = value end
                     },
					 PFPetDisableHealth = {
                        order = 204,
                        name = "Disable Pet Health Text",
                        desc = "Disable the Pet Health  text",
                        type = "toggle",
                        width = "single",
                        get = function() return db.PFPetDisableHealth end,
                        set = function(info, value) db.PFPetDisableHealth = value end
                     },
					 PetHealthFont = {
						order = 205,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Pet Health Font',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.PetHealthFont -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.PetHealthFont = key -- saves our new selection the the current one
						 end,
					},
					PetHealthFontOutline = {
						order = 206,
						type = 'select',
						 name = 'Pet Health font outline',
						 desc = 'Health font outline',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.PetHealthFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.PetHealthFontOutline = key -- saves our new selection the the current one
						 end,
					},
					PetHealthFontSize = {
                        order = 207,
                        name = "Pet Health Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 25,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.PetHealthFontSize end,
                        set = function(info, value) db.PetHealthFontSize = value end
                    },
					PFPetDisableManaPercent = {
                        order = 208,
                        name = "Disable Pet Power Percent",
                        desc = "Disable the Power Percent text",
                        type = "toggle",
                        width = "single",
                        get = function() return db.PFPetDisableManaPercent end,
                        set = function(info, value) db.PFPetDisableManaPercent = value end
                     },
					 PFPetDisableMana = {
                        order = 209,
                        name = "Disable Pet Power Text",
                        desc = "Disable the Power text",
                        type = "toggle",
                        width = "single",
                        get = function() return db.PFPetDisableMana end,
                        set = function(info, value) db.PFPetDisableMana = value end
                     },
					 PetManaFont = {
						order = 210,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Pet Power Font',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.PetManaFont -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.PetManaFont = key -- saves our new selection the the current one
						 end,
					},
					PetManaFontOutline = {
						order = 211,
						type = 'select',
						 name = 'Pet Power font outline',
						 desc = 'Power font outline',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.PetManaFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.PetManaFontOutline = key -- saves our new selection the the current one
						 end,
					},
					PetManaFontSize = {
                        order = 212,
                        name = "Pet Power Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 25,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.PetManaFontSize end,
                        set = function(info, value) db.PetManaFontSize = value end
                    },
					PFPetDisableLevel = {
                        order = 213,
                        name = "Disable Pet Level Text",
                        desc = "Disable the Level  text",
                        type = "toggle",
                        width = "single",
                        get = function() return db.PFPetDisableLevel end,
                        set = function(info, value) db.PFPetDisableLevel = value end
                     },
					 PetLevelFont = {
						order = 214,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Pet Level Font',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.PetLevelFont -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.PetLevelFont = key -- saves our new selection the the current one
						 end,
					},
					PetLevelFontOutline = {
						order = 215,
						type = 'select',
						 name = 'Pet Level font outline',
						 desc = 'Level font outline',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.PetLevelFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.PetLevelFontOutline = key -- saves our new selection the the current one
						 end,
					},
					PetLevelFontSize = {
                        order = 216,
                        name = "Pet Level Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 25,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.PetLevelFontSize end,
                        set = function(info, value) db.PetLevelFontSize = value end
                    },
					PFPetDisableName = {
                        order = 217,
                        name = "Disable Pet Name Text",
                        desc = "Disable the Pet Name  text",
                        type = "toggle",
                        width = "single",
                        get = function() return db.PFPetDisableName end,
                        set = function(info, value) db.PFPetDisableName = value end
                     },
					 PetNameFont = {
						order = 218,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Pet Name Font Name',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.PetNameFont -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.PetNameFont = key -- saves our new selection the the current one
						 end,
					},
					PetNameFontOutline = {
						order = 219,
						type = 'select',
						 name = 'Pet Name font outline',
						 desc = 'Name font outline',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.PetNameFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.PetNameFontOutline = key -- saves our new selection the the current one
						 end,
					},
					PetNameFontSize = {
                        order = 220,
                        name = "Pet Name Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 25,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.PetNameFontSize end,
                        set = function(info, value) db.PetNameFontSize = value end
                    },
					  PFPetDisablePortrait = {
                        order = 221,
                        name = "Disable Pet Portrait",
                        desc = "Disable the Portrait",
                        type = "toggle",
                        width = "double",
                        get = function() return db.PFPetDisablePortrait end,
                        set = function(info, value) db.PFPetDisablePortrait = value end
                     },
					 PFPetDisablePortraitBG = {
                        order = 222,
                        name = "Disable Pet Portrait Background",
                        desc = "Disable the Portrait Background",
                        type = "toggle",
                        width = "double",
                        get = function() return db.PFPetDisablePortraitBG end,
                        set = function(info, value) db.PFPetDisablePortraitBG = value end
                     },
					PetPortraitBGBlackOut = {
                        order = 223,
                        name = "Black Pet Portrait Background",
                        desc = "Black the Portrait Background",
                        type = "toggle",
                        width = "double",
                        get = function() return db.PetPortraitBGBlackOut end,
                        set = function(info, value) db.PetPortraitBGBlackOut = value end
                     },
                }
            },
			TargetFrame = {
                order = 400,
                name = "Target Frame",
                type = "group",
                args = {
				ReloadReminder = {
                        order = 1,
                        name = "Remember to Reload the UI (/rl) after adjusting the settings",
						fontSize  = "large",
                        desc = "Remember to Reload",
                        descStyle = "inline",
                        type = "description",
                        width = "full",
                    },
                     TargetFrame = {
                        order = 2,
                        name = "Disable",
                        desc = "Disable the TargetFrame",
                        descStyle = "inline",
                        type = "toggle",
                        width = "double",
                        get = function() return db.TargetFrameDisable end,
                        set = function(info, value) db.TargetFrameDisable = value end
                     },
					 TargetX = {
                        order = 3,
                        name = "Target Frame Left and Right",
                        desc = "Set the Left and Right point of the Target Frame if enabled",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.TargetX end,
                        set = function(info, value) db.TargetX = value end
                    },
					TargetY = {
                        order = 4,
                        name = "Target Frame Up and Down",
                        desc = "Set the Top and Bottom point of the Target Frame if enabled",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.TargetY end,
                        set = function(info, value) db.TargetY = value end
                    },
					  TargetFrameDisableCB = {
                        order =5,
                        name = "Disable Cast Bar",
                        desc = "Disable the Target Frame Cast Bar",                       
                        type = "toggle",
                        width = "single",
                        get = function() return db.TargetFrameDisableCB end,
                        set = function(info, value) db.TargetFrameDisableCB = value end
                     },
					 TargetFrameScale = {
                        order = 6,
                        name = "Target Frame Scale",
                        desc = "Overall scale of the Target Frame ",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 0.25,
						max = 4.5,
						step  = 0.05,
						bigStep = 0.05,
						isPercent = false,
                        get = function() return db.TargetFrameScale end,
                        set = function(info, value) db.TargetFrameScale = value end
                    },
					 
					 TargetFrameNoBorder = {
                        order = 7,
                        name = " No Border",
                        desc = "use no border color",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.TargetFrameNoBorder end,
                        set = function(info, value) db.TargetFrameNoBorder = value end
                     },
					 TargetFrameBorderSize = {
                        order = 8,
                        name = " Frame Border Size",
                        desc = "Change the TargetFrame Frame Border Size",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 0,
						max = 50,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.TargetFrameBorderSize end,
                        set = function(info, value) db.TargetFrameBorderSize = value end
                    },
					TargetFrameBorderPadding = {
                        order = 9,
                        name = "Border Padding",
                        desc = "Change the TargetFrame Frame Border Padding",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -10,
						max = 50,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.TargetFrameBorderPadding end,
                        set = function(info, value) db.TargetFrameBorderPadding = value end
                    },
					TargetFrameStatusBarHealth = {
						order = 10,
						type = 'select',
						 dialogControl = 'LSM30_Statusbar', 
						 name = 'Health Status Bars',
						 desc = 'Status Bars for peeps who like to change Status Bars',
						 values = LSM:HashTable("statusbar"),	 
						  get = function()
							  return db.TargetFrameStatusBarHealth -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.TargetFrameStatusBarHealth = key -- saves our new selection the the current one
						 end,
					},
					TargetFrameStatusBarPower = {
						order = 11,
						type = 'select',
						 dialogControl = 'LSM30_Statusbar', 
						 name = 'Power Status Bar',
						 desc = 'Status Bars  for peeps who like to change Status Bars',
						 values = LSM:HashTable("statusbar"),	 
						  get = function()
							  return db.TargetFrameStatusBarPower -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.TargetFrameStatusBarPower = key -- saves our new selection the the current one
						 end,
					},
					TargetFrameStatusBarCB = {
						order = 12,
						type = 'select',
						 dialogControl = 'LSM30_Statusbar', 
						 name = 'Cast Bar Status Bar',
						 desc = 'Status Bars  for peeps who like to change Status Bars',
						 values = LSM:HashTable("statusbar"),	 
						  get = function()
							  return db.TargetFrameStatusBarCB -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.TargetFrameStatusBarCB = key -- saves our new selection the the current one
						 end,
					},

					 TargetFrameDisableAuras = {
                        order = 202,
                        name = "Disable Auras",
                        desc = "Disable the TargetFrame Buffs/Debuffs/Auras",
                        type = "toggle",
                        width = "single",
                        get = function() return db.TargetFrameDisableAuras end,
                        set = function(info, value) db.TargetFrameDisableAuras = value end
                     },
					 TargetFrameDisableHealthPercent = {
                        order = 203,
                        name = "Disable Health Percent",
                        desc = "Disable the TargetFrame Health Percent text",
                        type = "toggle",
                        width = "single",
                        get = function() return db.TargetFrameDisableHealthPercent end,
                        set = function(info, value) db.TargetFrameDisableHealthPercent = value end
                     },
					 TargetFrameDisableHealth = {
                        order = 204,
                        name = "Disable Health Text",
                        desc = "Disable the TargetFrame Health  text",
                        type = "toggle",
                        width = "single",
                        get = function() return db.TargetFrameDisableHealth end,
                        set = function(info, value) db.TargetFrameDisableHealth = value end
                     },
					 TargetFrameHealthFont = {
						order = 205,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Health Font',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.TargetFrameHealthFont -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.TargetFrameHealthFont = key -- saves our new selection the the current one
						 end,
					},
					TargetFrameHealthFontOutline = {
						order = 206,
						type = 'select',
						 name = 'Health font outline',
						 desc = 'Health font outline',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.TargetFrameHealthFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							
							  db.TargetFrameHealthFontOutline = key -- saves our new selection the the current one
						
						 end,
					},
					TargetFrameHealthFontSize = {
                        order = 207,
                        name = "Health Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 25,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.TargetFrameHealthFontSize end,
                        set = function(info, value) db.TargetFrameHealthFontSize = value end
                    },
					TargetFrameDisableManaPercent = {
                        order = 208,
                        name = "Disable Power Percent",
                        desc = "Disable the Power Percent text",
                        type = "toggle",
                        width = "single",
                        get = function() return db.TargetFrameDisableManaPercent end,
                        set = function(info, value) db.TargetFrameDisableManaPercent = value end
                     },
					 TargetFrameDisableMana = {
                        order = 209,
                        name = "Disable Power Text",
                        desc = "Disable the Power  text",
                        type = "toggle",
                        width = "single",
                        get = function() return db.TargetFrameDisableMana end,
                        set = function(info, value) db.TargetFrameDisableMana = value end
                     },
					 TargetFrameManaFont = {
						order = 210,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Power Font',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.TargetFrameManaFont -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.TargetFrameManaFont = key -- saves our new selection the the current one
						 end,
					},
					TargetFrameManaFontOutline = {
						order = 211,
						type = 'select',
						 name = 'Power font outline',
						 desc = 'Power font outline',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.TargetFrameManaFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							
							  db.TargetFrameManaFontOutline = key -- saves our new selection the the current one
						
						 end,
					},
					TargetFrameManaFontSize = {
                        order = 212,
                        name = "Power Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 25,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.TargetFrameManaFontSize end,
                        set = function(info, value) db.TargetFrameManaFontSize = value end
                    },
					TargetFrameDisableLevel = {
                        order = 213,
                        name = "Disable Level Text",
                        desc = "Disable the Target Frame Level  text",
                        type = "toggle",
                        width = "single",
                        get = function() return db.TargetFrameDisableLevel end,
                        set = function(info, value) db.TargetFrameDisableLevel = value end
                     },
					 TargetFrameLevelFont = {
						order = 214,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Level Font',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.TargetFrameLevelFont -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.TargetFrameLevelFont = key -- saves our new selection the the current one
						 end,
					},
					TargetFrameLevelFontOutline = {
						order = 215,
						type = 'select',
						 name = 'Level font outline',
						 desc = 'Level font outline',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.TargetFrameLevelFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							
							  db.TargetFrameLevelFontOutline = key -- saves our new selection the the current one
						
						 end,
					},
					TargetFrameLevelFontSize = {
                        order = 216,
                        name = "Level Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 25,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.TargetFrameLevelFontSize end,
                        set = function(info, value) db.TargetFrameLevelFontSize = value end
                    },
					TargetFrameDisableName = {
                        order = 217,
                        name = "Disable Name Text",
                        desc = "Disable the Target Frame Name  text",
                        type = "toggle",
                        width = "single",
                        get = function() return db.TargetFrameDisableName end,
                        set = function(info, value) db.TargetFrameDisableName = value end
                     },
					 TargetFrameNameFont = {
						order = 218,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Name Font',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.TargetFrameNameFont -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.TargetFrameNameFont = key -- saves our new selection the the current one
						 end,
					},
					TargetFrameNameFontOutline = {
						order = 219,
						type = 'select',
						 name = 'Name font outline',
						 desc = 'Name font outline',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.TargetFrameNameFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							
							  db.TargetFrameNameFontOutline = key -- saves our new selection the the current one
						
						 end,
					},
					TargetFrameNameFontSize = {
                        order = 220,
                        name = "Name Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 25,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.TargetFrameNameFontSize end,
                        set = function(info, value) db.TargetFrameNameFontSize = value end
                    },
					 TargetFrameFloatingCombatText = {
                        order = 221,
                        name = "Floating Combat Text",
                        desc = "Turns off the Floating Combat text",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.TargetFrameFloatingCombatText end,
                        set = function(info, value) db.TargetFrameFloatingCombatText = value end
                     },
					 
					 TargetFrameFCFNameFont = {
						order = 222,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Floating Combat Text Font Name',
						 desc = 'Floating Combat Text Font Name',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.TargetFrameFCFNameFont -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.TargetFrameFCFNameFont = key -- saves our new selection the the current one
						 end,
					},
					TargetFrameFCFNameFontOutline = {
						order = 223,
						type = 'select',
						 name = 'Floating Combat Text font outline',
						 desc = 'Floating Combat Text font outline',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.TargetFrameFCFNameFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							
							  db.TargetFrameFCFNameFontOutline = key -- saves our new selection the the current one
						
						 end,
					},
					TargetFrameFCFNameFontSize = {
                        order = 224,
                        name = "Floating Combat Text Name Font Size",
                        desc = "Target Frame Floating Combat Text Name Font Size",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 65,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.TargetFrameFCFNameFontSize end,
                        set = function(info, value) db.TargetFrameFCFNameFontSize = value end
                    },
					  TargetFrameDisablePortrait = {
                        order = 225,
                        name = "Disable Portrait",
                        desc = "Disable the Portrait",
                        type = "toggle",
                        width = "double",
                        get = function() return db.TargetFrameDisablePortrait end,
                        set = function(info, value) db.TargetFrameDisablePortrait = value end
                     },				
                }
            },	
			ToT = {
                order = 500,
                name = "Target of Target",
                type = "group",
                args = {
				ReloadReminder = {
                        order = 1,
                        name = "Remember to Reload the UI (/rl) after adjusting the settings",
						fontSize  = "large",
                        desc = "Remember to Reload",
                        descStyle = "inline",
                        type = "description",
                        width = "full",
                       
                    },
                   ToTFrameDiable = {
                        order = 2,
                        name = "Disable",
                        desc = "Disable the Target Target Frame",
                        descStyle = "inline",
                        type = "toggle",
                        width = "double",
                        get = function() return db.ToTFrameDiable end,
                        set = function(info, value) db.ToTFrameDiable = value end
                     },
					  TotX = {
                        order = 3,
                        name = "Target of Target Frame Left and Right",
                        desc = "Set the Left and Right point of the Target of Target Frame if enabled",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.TotX end,
                        set = function(info, value) db.TotX = value end
                    },
					TotY = {
                        order = 4,
                        name = "Target of Target Frame Up and Down",
                        desc = "Set the Top and Bottom point of the Target of Target Frame if enabled",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.TotY end,
                        set = function(info, value) db.TotY = value end
                    },
					 ToTFrameScale = {
                        order = 5,
                        name = "Frame Scale",
                        desc = "Overall scale of the Target Target Frame",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 0.25,
						max = 4.5,
						step  = 0.05,
						bigStep = 0.05,
						isPercent = false,
                        get = function() return db.ToTFrameScale end,
                        set = function(info, value) db.ToTFrameScale = value end
                    },
					 ToTFrameNoBorder = {
                        order = 6,
                        name = "No Border",
                        desc = "use no border color",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.ToTFrameNoBorder end,
                        set = function(info, value) db.ToTFrameNoBorder = value end
                     },
					 ToTFrameBorderSize = {
                        order = 7,
                        name = "Border Size",
                        desc = "Change the Target Target Frame Border Size",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 0,
						max = 50,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.ToTFrameBorderSize end,
                        set = function(info, value) db.ToTFrameBorderSize = value end
                    },
					ToTFrameBorderPadding = {
                        order = 8,
                        name = "Border Padding",
                        desc = "Change the Target Target Frame Border Padding",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -10,
						max = 50,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.ToTFrameBorderPadding end,
                        set = function(info, value) db.ToTFrameBorderPadding = value end
                    },
					ToTFrameStatusBarHealth = {
						order = 9,
						type = 'select',
						 dialogControl = 'LSM30_Statusbar', 
						 name = 'Health Status Bars',
						 desc = 'Status Bars for peeps who like to change Status Bars',
						 values = LSM:HashTable("statusbar"),	 
						  get = function()
							  return db.ToTFrameStatusBarHealth -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.ToTFrameStatusBarHealth = key -- saves our new selection the the current one
						 end,
					},
					ToTFrameStatusBarPower = {
						order = 10,
						type = 'select',
						 dialogControl = 'LSM30_Statusbar', 
						 name = 'Power Status Bar',
						 desc = 'Status Bars  for peeps who like to change Status Bars',
						 values = LSM:HashTable("statusbar"),	 
						  get = function()
							  return db.ToTFrameStatusBarPower -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.ToTFrameStatusBarPower = key -- saves our new selection the the current one
						 end,
						 },
					 ToTFrameDisableHealth = {
                        order = 204,
                        name = "Disable Health Text",
                        desc = "Disable the TargetFrame Health  text",
                        type = "toggle",
                        width = "single",
                        get = function() return db.ToTFrameDisableHealth end,
                        set = function(info, value) db.ToTFrameDisableHealth = value end
                     },
					 ToTFrameHealthFont = {
						order = 205,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Health Font',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.ToTFrameHealthFont -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.ToTFrameHealthFont = key -- saves our new selection the the current one
						 end,
					},
					ToTFrameHealthFontOutline = {
						order = 206,
						type = 'select',
						 name = 'Health font outline',
						 desc = 'Health font outline',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.ToTFrameHealthFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							
							  db.ToTFrameHealthFontOutline = key -- saves our new selection the the current one
						
						 end,
					},
					ToTFrameHealthFontSize = {
                        order = 207,
                        name = "Health Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 25,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.ToTFrameHealthFontSize end,
                        set = function(info, value) db.ToTFrameHealthFontSize = value end
                    },
					ToTFrameDisableMana = {
                        order = 209,
                        name = "Disable Power Text",
                        desc = "Disable the Power text",
                        type = "toggle",
                        width = "single",
                        get = function() return db.ToTFrameDisableMana end,
                        set = function(info, value) db.ToTFrameDisableMana = value end
                     },
					 ToTFrameManaFont = {
						order = 210,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Power Font',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.ToTFrameManaFont -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.ToTFrameManaFont = key -- saves our new selection the the current one
						 end,
					},
					ToTFrameManaFontOutline = {
						order = 211,
						type = 'select',
						 name = 'Power font outline',
						 desc = 'Power font outline',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.ToTFrameManaFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							
							  db.ToTFrameManaFontOutline = key -- saves our new selection the the current one
						
						 end,
					},
					ToTFrameManaFontSize = {
                        order = 212,
                        name = "Power Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 25,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.ToTFrameManaFontSize end,
                        set = function(info, value) db.ToTFrameManaFontSize = value end
                    },
					ToTFrameDisableName = {
                        order = 217,
                        name = "Disable Name Text",
                        desc = "Disable the TargetFrame Name  text",
                        type = "toggle",
                        width = "single",
                        get = function() return db.ToTFrameDisableName end,
                        set = function(info, value) db.ToTFrameDisableName = value end
                     },
					 ToTFrameNameFont = {
						order = 218,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Name Font',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.ToTFrameNameFont -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.ToTFrameNameFont = key -- saves our new selection the the current one
						 end,
					},
					ToTFrameNameFontOutline = {
						order = 219,
						type = 'select',
						 name = 'Name font outline',
						 desc = 'Name font outline',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.ToTFrameNameFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							
							  db.ToTFrameNameFontOutline = key -- saves our new selection the the current one
						
						 end,
					},
					ToTFrameNameFontSize = {
                        order = 220,
                        name = "Name Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 25,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.ToTFrameNameFontSize end,
                        set = function(info, value) db.ToTFrameNameFontSize = value end
                    },

                }
            },
			FocusFrame = {
                order = 600,
                name = "Focus Frame",
                type = "group",
                args = {
				ReloadReminder = {
                        order = 1,
                        name = "Remember to Reload the UI (/rl) after adjusting the settings",
						fontSize  = "large",
                        desc = "Remember to Reload",
                        descStyle = "inline",
                        type = "description",
                        width = "full",
                    },
                     FocusFrame = {
                        order = 2,
                        name = "Disable",
                        desc = "Disable the Focus Frame",
                        descStyle = "inline",
                        type = "toggle",
                        width = "double",
                        get = function() return db.FocusFrameDisable end,
                        set = function(info, value) db.FocusFrameDisable = value end
                     },
					 FocusX = {
                        order = 3,
                        name = "Focus Frame Left and Right",
                        desc = "Set the Left and Right point of the Focus Frame if enabled",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.FocusX end,
                        set = function(info, value) db.FocusX = value end
                    },
					FocusY = {
                        order = 4,
                        name = "Focus Frame Up and Down",
                        desc = "Set the Top and Bottom point of the Focus Frame if enabled",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.FocusY end,
                        set = function(info, value) db.FocusY = value end
                    },
					  FocusFrameDisableCB = {
                        order = 5,
                        name = "Disable Cast Bar",
                        desc = "Disable the Focus Frame Cast Bar",                       
                        type = "toggle",
                        width = "single",
                        get = function() return db.FocusFrameDisableCB end,
                        set = function(info, value) db.FocusFrameDisableCB = value end
                     },
					 FocusFrameScale = {
                        order = 6,
                        name = "Frame Scale",
                        desc = "Overall scale of the Focus Frame",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 0.25,
						max = 4.5,
						step  = 0.05,
						bigStep = 0.05,
						isPercent = false,
                        get = function() return db.FocusFrameScale end,
                        set = function(info, value) db.FocusFrameScale = value end
                    },
					 
					 FocusFrameNoBorder = {
                        order = 7,
                        name = "No Border",
                        desc = "use no border color",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.FocusFrameNoBorder end,
                        set = function(info, value) db.FocusFrameNoBorder = value end
                     },
					 FocusFrameBorderSize = {
                        order = 8,
                        name = "Border Size",
                        desc = "Change the Focus Frame Border Size",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 0,
						max = 50,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.FocusFrameBorderSize end,
                        set = function(info, value) db.FocusFrameBorderSize = value end
                    },
					FocusFrameBorderPadding = {
                        order = 9,
                        name = "Border Padding",
                        desc = "Change the Focus Frame Border Padding",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -10,
						max = 50,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.FocusFrameBorderPadding end,
                        set = function(info, value) db.FocusFrameBorderPadding = value end
                    },
					FocusFrameStatusBarHealth = {
						order = 10,
						type = 'select',
						 dialogControl = 'LSM30_Statusbar', 
						 name = 'Health Status Bars',
						 desc = 'Status Bars for peeps who like to change Status Bars',
						 values = LSM:HashTable("statusbar"),	 
						  get = function()
							  return db.FocusFrameStatusBarHealth -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.FocusFrameStatusBarHealth = key -- saves our new selection the the current one
						 end,
					},
					FocusFrameStatusBarPower = {
						order = 11,
						type = 'select',
						 dialogControl = 'LSM30_Statusbar', 
						 name = 'Power Status Bar',
						 desc = 'Status Bars for peeps who like to change Status Bars',
						 values = LSM:HashTable("statusbar"),	 
						  get = function()
							  return db.FocusFrameStatusBarPower -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.FocusFrameStatusBarPower = key -- saves our new selection the the current one
						 end,
					},
					FocusFrameStatusBarCB = {
						order = 12,
						type = 'select',
						 dialogControl = 'LSM30_Statusbar', 
						 name = 'Cast Bar Status Bar',
						 desc = 'Status Bars for peeps who like to change Status Bars',
						 values = LSM:HashTable("statusbar"),	 
						  get = function()
							  return db.FocusFrameStatusBarCB -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.FocusFrameStatusBarCB = key -- saves our new selection the the current one
						 end,
					},

					 FocusFrameDisableAuras = {
                        order = 202,
                        name = "Disable Auras",
                        desc = "Disable Focus Frame Buffs/Debuffs/Auras",
                        type = "toggle",
                        width = "single",
                        get = function() return db.FocusFrameDisableAuras end,
                        set = function(info, value) db.FocusFrameDisableAuras = value end
                     },
					 FocusFrameDisableHealthPercent = {
                        order = 203,
                        name = "Disable Health Percent",
                        desc = "Disable the Focus Frame Health Percent text",
                        type = "toggle",
                        width = "single",
                        get = function() return db.FocusFrameDisableHealthPercent end,
                        set = function(info, value) db.FocusFrameDisableHealthPercent = value end
                     },
					 FocusFrameDisableHealth = {
                        order = 204,
                        name = "Disable Health Text",
                        desc = "Disable the Focus Frame Health  text",
                        type = "toggle",
                        width = "single",
                        get = function() return db.FocusFrameDisableHealth end,
                        set = function(info, value) db.FocusFrameDisableHealth = value end
                     },
					 FocusFrameHealthFont = {
						order = 205,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Health Font',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.FocusFrameHealthFont -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.FocusFrameHealthFont = key -- saves our new selection the the current one
						 end,
					},
					FocusFrameHealthFontOutline = {
						order = 206,
						type = 'select',
						 name = 'Health font outline',
						 desc = 'Health font outline',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.FocusFrameHealthFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							
							  db.FocusFrameHealthFontOutline = key -- saves our new selection the the current one
						
						 end,
					},
					FocusFrameHealthFontSize = {
                        order = 207,
                        name = "Health Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 25,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.FocusFrameHealthFontSize end,
                        set = function(info, value) db.FocusFrameHealthFontSize = value end
                    },
					FocusFrameDisableManaPercent = {
                        order = 208,
                        name = "Disable Power Percent",
                        desc = "Disable the Power Percent text",
                        type = "toggle",
                        width = "single",
                        get = function() return db.FocusFrameDisableManaPercent end,
                        set = function(info, value) db.FocusFrameDisableManaPercent = value end
                     },
					 FocusFrameDisableMana = {
                        order = 209,
                        name = "Disable Power Text",
                        desc = "Disable the Power  text",
                        type = "toggle",
                        width = "single",
                        get = function() return db.FocusFrameDisableMana end,
                        set = function(info, value) db.FocusFrameDisableMana = value end
                     },
					 FocusFrameManaFont = {
						order = 210,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Power Font',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.FocusFrameManaFont -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.FocusFrameManaFont = key -- saves our new selection the the current one
						 end,
					},
					FocusFrameManaFontOutline = {
						order = 211,
						type = 'select',
						 name = 'Power font outline',
						 desc = 'Power font outline',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.FocusFrameManaFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							
							  db.FocusFrameManaFontOutline = key -- saves our new selection the the current one
						
						 end,
					},
					FocusFrameManaFontSize = {
                        order = 212,
                        name = "Power Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 25,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.FocusFrameManaFontSize end,
                        set = function(info, value) db.FocusFrameManaFontSize = value end
                    },
					FocusFrameDisableLevel = {
                        order = 213,
                        name = "Disable Level Text",
                        desc = "Disable the Focus Frame Level  text",
                        type = "toggle",
                        width = "single",
                        get = function() return db.FocusFrameDisableLevel end,
                        set = function(info, value) db.FocusFrameDisableLevel = value end
                     },
					 FocusFrameLevelFont = {
						order = 214,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Level Font',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.FocusFrameLevelFont -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.FocusFrameLevelFont = key -- saves our new selection the the current one
						 end,
					},
					FocusFrameLevelFontOutline = {
						order = 215,
						type = 'select',
						 name = 'Level font outline',
						 desc = 'Level font outline',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.FocusFrameLevelFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							
							  db.FocusFrameLevelFontOutline = key -- saves our new selection the the current one
						
						 end,
					},
					FocusFrameLevelFontSize = {
                        order = 216,
                        name = "Level Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 25,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.FocusFrameLevelFontSize end,
                        set = function(info, value) db.FocusFrameLevelFontSize = value end
                    },
					FocusFrameDisableName = {
                        order = 217,
                        name = "Disable Name Text",
                        desc = "Disable the Focus Frame Name  text",
                        type = "toggle",
                        width = "single",
                        get = function() return db.FocusFrameDisableName end,
                        set = function(info, value) db.FocusFrameDisableName = value end
                     },
					 FocusFrameNameFont = {
						order = 218,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Name Font',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.FocusFrameNameFont -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.FocusFrameNameFont = key -- saves our new selection the the current one
						 end,
					},
					FocusFrameNameFontOutline = {
						order = 219,
						type = 'select',
						 name = 'Name font outline',
						 desc = 'Name font outline',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.FocusFrameNameFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							
							  db.FocusFrameNameFontOutline = key -- saves our new selection the the current one
						
						 end,
					},
					FocusFrameNameFontSize = {
                        order = 220,
                        name = "Name Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 25,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.FocusFrameNameFontSize end,
                        set = function(info, value) db.FocusFrameNameFontSize = value end
                    },
					 					 
					  FocusFrameDisablePortrait = {
                        order = 225,
                        name = "Disable Portrait",
                        desc = "Disable the Portrait",
                        type = "toggle",
                        width = "double",
                        get = function() return db.FocusFrameDisablePortrait end,
                        set = function(info, value) db.FocusFrameDisablePortrait = value end
                     },
					
					
                }
            },
			FT = {
                order = 700,
                name = "Focus Target",
                type = "group",
                args = {
				ReloadReminder = {
                        order = 1,
                        name = "Remember to Reload the UI (/rl) after adjusting the settings",
						fontSize  = "large",
                        desc = "Remember to Reload",
                        descStyle = "inline",
                        type = "description",
                        width = "full",
                       
                    },
                   FTFrameDiable = {
                        order = 2,
                        name = "Disable",
                        desc = "Disable the Focus Target",
                        descStyle = "inline",
                        type = "toggle",
                        width = "double",
                        get = function() return db.FTFrameDiable end,
                        set = function(info, value) db.FTFrameDiable = value end
                     },
					 FocusTX = {
                        order = 3,
                        name = "Focus Target Frame Left and Right",
                        desc = "Set the Left and Right point of the Focus Target Frame if enabled",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.FocusTX end,
                        set = function(info, value) db.FocusTX = value end
                    },
					FocusTY = {
                        order = 4,
                        name = "Focus Target Frame Up and Down",
                        desc = "Set the Top and Bottom point of the Focus Target Frame if enabled",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.FocusTY end,
                        set = function(info, value) db.FocusTY = value end
                    },
					 FTFrameScale = {
                        order = 4,
                        name = "Frame Scale",
                        desc = "Overall scale of the Focus Target Frame",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 0.25,
						max = 4.5,
						step  = 0.05,
						bigStep = 0.05,
						isPercent = false,
                        get = function() return db.FTFrameScale end,
                        set = function(info, value) db.FTFrameScale = value end
                    },
					 FTFrameNoBorder = {
                        order = 5,
                        name = "No Border",
                        desc = "use no border color",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.FTFrameNoBorder end,
                        set = function(info, value) db.FTFrameNoBorder = value end
                     },
					 FTFrameBorderSize = {
                        order = 7,
                        name = "Border Size",
                        desc = "Change the TargetFrame Frame Border Size",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 0,
						max = 50,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.FTFrameBorderSize end,
                        set = function(info, value) db.FTFrameBorderSize = value end
                    },
					FTFrameBorderPadding = {
                        order = 8,
                        name = "Border Padding",
                        desc = "Change the Focus Target Frame Border Padding",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -10,
						max = 50,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.FTFrameBorderPadding end,
                        set = function(info, value) db.FTFrameBorderPadding = value end
                    },
					FTFrameStatusBarHealth = {
						order = 9,
						type = 'select',
						 dialogControl = 'LSM30_Statusbar', 
						 name = 'Health Status Bars',
						 desc = 'Status Bars for peeps who like to change Status Bars',
						 values = LSM:HashTable("statusbar"),	 
						  get = function()
							  return db.FTFrameStatusBarHealth -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.FTFrameStatusBarHealth = key -- saves our new selection the the current one
						 end,
					},
					FTFrameStatusBarPower = {
						order = 10,
						type = 'select',
						 dialogControl = 'LSM30_Statusbar', 
						 name = 'Power Status Bar',
						 desc = 'Status Bars for peeps who like to change Status Bars',
						 values = LSM:HashTable("statusbar"),	 
						  get = function()
							  return db.FTFrameStatusBarPower -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.FTFrameStatusBarPower = key -- saves our new selection the the current one
						 end,
						 },
					 FTFrameDisableHealth = {
                        order = 204,
                        name = "DisableHealth Text",
                        desc = "Disable the Focus Target Frame Health text",
                        type = "toggle",
                        width = "single",
                        get = function() return db.FTFrameDisableHealth end,
                        set = function(info, value) db.FTFrameDisableHealth = value end
                     },
					 FTFrameHealthFont = {
						order = 205,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Health Font',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.FTFrameHealthFont -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.FTFrameHealthFont = key -- saves our new selection the the current one
						 end,
					},
					FTFrameHealthFontOutline = {
						order = 206,
						type = 'select',
						 name = 'Health font outline',
						 desc = 'Health font outline',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.FTFrameHealthFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							
							  db.FTFrameHealthFontOutline = key -- saves our new selection the the current one
						
						 end,
					},
					FTFrameHealthFontSize = {
                        order = 207,
                        name = "Health Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 25,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.FTFrameHealthFontSize end,
                        set = function(info, value) db.FTFrameHealthFontSize = value end
                    },
					FTFrameDisableMana = {
                        order = 209,
                        name = "Disable Power Text",
                        desc = "Disable the Power text",
                        type = "toggle",
                        width = "single",
                        get = function() return db.FTFrameDisableMana end,
                        set = function(info, value) db.FTFrameDisableMana = value end
                     },
					 FTFrameManaFont = {
						order = 210,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Power Font',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.FTFrameManaFont -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.FTFrameManaFont = key -- saves our new selection the the current one
						 end,
					},
					FTFrameManaFontOutline = {
						order = 211,
						type = 'select',
						 name = 'Power font outline',
						 desc = 'Power font outline',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.FTFrameManaFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							
							  db.FTFrameManaFontOutline = key -- saves our new selection the the current one
						
						 end,
					},
					FTFrameManaFontSize = {
                        order = 212,
                        name = "Power Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 25,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.FTFrameManaFontSize end,
                        set = function(info, value) db.FTFrameManaFontSize = value end
                    },
					FTFrameDisableName = {
                        order = 217,
                        name = "Disable Name Text",
                        desc = "Disable the Focus Target Frame Name text",
                        type = "toggle",
                        width = "single",
                        get = function() return db.FTFrameDisableName end,
                        set = function(info, value) db.FTFrameDisableName = value end
                     },
					 FTFrameNameFont = {
						order = 218,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Name Font',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.FTFrameNameFont -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.FTFrameNameFont = key -- saves our new selection the the current one
						 end,
					},
					FTFrameNameFontOutline = {
						order = 219,
						type = 'select',
						 name = 'Name font outline',
						 desc = 'Name font outline',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.FTFrameNameFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							
							  db.FTFrameNameFontOutline = key -- saves our new selection the the current one
						
						 end,
					},
					FTFrameNameFontSize = {
                        order = 220,
                        name = "Name Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 25,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.FTFrameNameFontSize end,
                        set = function(info, value) db.FTFrameNameFontSize = value end
                    },

                }
            },	
			Party = {
                order = 800,
                name = "Party",
                type = "group",
                args = {
				ReloadReminder = {
                        order = 1,
                        name = "Remember to Reload the UI (/rl) after adjusting the settings",
						fontSize  = "large",
                        desc = "Remember to Reload",
                        descStyle = "inline",
                        type = "description",
                        width = "full",
                       
                    },
                   
                    EnableParty = {
                        order = 1000,
                        name = "Enable Party Frames",
                        desc = "Enable Party Frames",
                        type = "toggle",
                        width = "full",
                        get = function() return db.EnableParty end,
                        set = function(info, value) db.EnableParty = value end
                    },
					SoloParty = {
                        order = 1001,
                        name = "Show Solo",
                        desc = "Show Solo",
                        type = "toggle",
                        width = "full",
                        get = function() return db.SoloParty end,
                        set = function(info, value) db.SoloParty = value end
                    },
					PartyX = {
                        order = 1003,
                        name = "Party Frame Set Left and Right",
                        desc = "Set the Left and Right point of the Party Frame Set if enabled",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.PartyX end,
                        set = function(info, value) db.PartyX = value end
                    },
					PartyY = {
                        order = 1004,
                        name = "Party Frame Set Up and Down",
                        desc = "Set the Top and Bottom point of the Party Frame Set if enabled",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.PartyY end,
                        set = function(info, value) db.PartyY = value end
                    },

                }
            },
			Raid = {
                order = 900,
                name = "Raid",
                type = "group",
                args = {
				ReloadReminder = {
                        order = 1,
                        name = "Remember to Reload the UI (/rl) after adjusting the settings",
						fontSize  = "large",
                        desc = "Remember to Reload",
                        descStyle = "inline",
                        type = "description",
                        width = "full",
                       
                    },
                   
                    EnableRaid = {
                        order = 1000,
                        name = "Enable Raid Frames",
                        desc = "Enable Raid Frames",
                        type = "toggle",
                        width = "full",
                        get = function() return db.EnableRaid end,
                        set = function(info, value) db.EnableRaid = value end
                    },
					 SoloRaid = {
                        order = 1001,
                        name = "Show Solo",
                        desc = "Show Solo",
                        type = "toggle",
                        width = "full",
                        get = function() return db.SoloRaid end,
                        set = function(info, value) db.SoloRaid = value end
                    },
					RaidX = {
                        order = 1003,
                        name = "Raid Frame Set Left and Right",
                        desc = "Set the Left and Right point of the Raid Frame Set if enabled",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.RaidX end,
                        set = function(info, value) db.RaidX = value end
                    },
					RaidY = {
                        order = 1004,
                        name = "Raid Frame Set Up and Down",
                        desc = "Set the Top and Bottom point of the Raid Frame Set if enabled",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.RaidY end,
                        set = function(info, value) db.RaidY = value end
                    },

                }
            },			
			MySystem = {
                order = 1000,
                name = "System",
                type = "group",
                args = {
				ReloadReminder = {
                        order = 1,
                        name = "Remember to Reload the UI (/rl) after adjusting the settings",
						fontSize  = "large",
                        desc = "Remember to Reload",
                        descStyle = "inline",
                        type = "description",
                        width = "full",
                       
                    },
                     AutoVender = {
                        order = 801,
                        name = "Auto Vender",
                        desc = "Automatically venders grey items",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.AutoVender end,
                        set = function(info, value) db.AutoVender = value end
                     },
					 AutoRepair = {
                        order = 802,
                        name = "Auto Repair",
                        desc = "Automatically Repairs you - Player",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.AutoRepair end,
                        set = function(info, value) db.AutoRepair = value end
                     },
					 QuestFrame = {
                        order = 803,
                        name = "Quest Frame",
                        desc = "Use the modified Quest Frame?",
                        descStyle = "inline",
                        type = "toggle",
                        width = "double",
                        get = function() return db.QuestFrame end,
                        set = function(info, value) db.QuestFrame = value end
                     },
					 QuestFont = {
						order = 804,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Quest Font',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.QuestFontKey -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.QuestFontKey = key -- saves our new selection the the current one
						 end,
					},
					QuestFontOutline = {
					order = 805,
						type = 'select',
						 name = 'Quest Font Outline',
						 desc = 'Status Bars for peeps who like to change fonts',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.QuestFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							
							  db.QuestFontOutline = key -- saves our new selection the the current one
						
						 end,
					},
					QuestFontSize = {
                        order = 806,
                        name = "Quest Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 100,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.QuestFontSize end,
                        set = function(info, value) db.QuestFontSize = value end
                    },
					 ComabatAlert = {
                        order = 807,
                        name = "Comabat Alert",
                        desc = "Use the Comabat Alert?",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.ComabatAlert end,
                        set = function(info, value) db.ComabatAlert = value end
                     },
					 AFK = {
                        order = 808,
                        name = "AFK",
                        desc = "Use the AFK alert?",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.AFK end,
                        set = function(info, value) db.AFK = value end
                     },
					 ShowGold = {
                        order = 809,
                        name = "Show Gold",
                        desc = "Show Gold Text?",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.ShowGold end,
                        set = function(info, value) db.ShowGold = value end
                     },
					 GoldX = {
                        order = 810,
                        name = "Gold Left and Right",
                        desc = "Set the Left and Right point of the Gold text if enabled",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.GoldX end,
                        set = function(info, value) db.GoldX = value end
                    },
					GoldY = {
                        order = 811,
                        name = "Gold Up and Down",
                        desc = "Set the Top and Bottom point of the Gold text if enabled",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.GoldY end,
                        set = function(info, value) db.GoldY = value end
                    },
					 GoldFont = {
						order = 812,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Gold Font Name',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.GoldFontKey -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.GoldFontKey = key -- saves our new selection the the current one
						 end,
					},
					GoldFontOutline = {
						order = 813,
						type = 'select',
						 name = 'Gold Font Outline',
						 desc = 'Status Bars for peeps who like to change fonts',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.GoldFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							
							  db.GoldFontOutline = key -- saves our new selection the the current one
						
						 end,
					},
					GoldFontSize = {
                        order = 814,
                        name = "Gold Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 100,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.GoldFontSize end,
                        set = function(info, value) db.GoldFontSize = value end
                    },
					 ShowDura = {
                        order = 815,
                        name = "Show Durability",
                        desc = "Show Durability Text?",
                        descStyle = "inline",
                        type = "toggle",
                        width = "single",
                        get = function() return db.ShowDura end,
                        set = function(info, value) db.ShowDura = value end
                     },
					 DuraX = {
                        order = 816,
                        name = "Durabilty Left and Right",
                        desc = "Set the Left and Right point of the Durabilty text if enabled",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.DuraX end,
                        set = function(info, value) db.DuraX = value end
                    },
					DuraY = {
                        order = 817,
                        name = "Durabilty Up and Down",
                        desc = "Set the Top and Bottom point of the Durabilty text if enabled",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.DuraY end,
                        set = function(info, value) db.DuraY = value end
                    },
					 
					 DuraFont = {
						order = 818,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Durability Font Name',
						 desc = 'Fonts for peeps who like to change fonts',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.DuraFontKey -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.DuraFontKey = key -- saves our new selection the the current one
						 end,
					},
					DuraFontOutline = {
						order = 819,
						type = 'select',
						 name = 'Durability Font Outline',
						 desc = 'Status Bars for peeps who like to change fonts',
						 values = {"None","MonoChrome","Thin","Thick"},
						  get = function()
							  return db.DuraFontOutline -- variable that is my current selection
						 end,
						 set = function(self,key)
							
							  db.DuraFontOutline = key -- saves our new selection the the current one
						
						 end,
					},
					DuraFontSize = {
                        order = 820,
                        name = "Durability Font Size",
                        desc = "Size of the font",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = 5,
						max = 100,
						step  = 1,
						bigStep = 1,
						isPercent = false,
                        get = function() return db.DuraFontSize end,
                        set = function(info, value) db.DuraFontSize = value end
                    },
					 VehicleX = {
                        order = 821,
                        name = "Vehicle Frame Left and Right",
                        desc = "Set the Left and Right point of the Vehicle Frame if enabled",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.VehicleX end,
                        set = function(info, value) db.VehicleX = value end
                    },
					VehicleY = {
                        order = 822,
                        name = "Vehicle Frame Up and Down",
                        desc = "Set the Top and Bottom point of the Vehicle Frame if enabled",
                        descStyle = "inline",
                        type = "range",
                        width = "double",
						min = -2500,
						max = 2500,
						step  = 1,
						bigStep = 5,
						isPercent = false,
                        get = function() return db.VehicleY end,
                        set = function(info, value) db.VehicleY = value end
                    },
					ChatTab = {
						order = 823,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Chat Tab Font Name',
						 desc = 'Change the font of teh Chat Tab',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.ChatTabKey -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.ChatTabKey = key -- saves our new selection the the current one
						 end,
					},
					ChatEdit = {
						order = 824,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Chat Edit Font Name',
						 desc = 'Change the font of the Edit Box aka /say I am keivamp',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.ChatEditKey -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.ChatEditKey = key -- saves our new selection the the current one
						 end,
					},
					Chat = {
						order = 825,
						type = 'select',
						 dialogControl = 'LSM30_Font', 
						 name = 'Chat Font Name',
						 desc = 'Change the font of the Chat Body',
						 values = LSM:HashTable("font"),				
						  get = function()
							  return db.ChatKey -- variable that is my current selection
						 end,
						 set = function(self,key)
							  db.ChatKey = key -- saves our new selection the the current one
						 end,
					},
					
				
                }
            },
			Reset = {
                order = 1100,
                name = "Reset",
                type = "group",
                args = {
				ReloadReminder = {
                        order = 1,
                        name = "Remember to Reload the UI (/rl) after adjusting the settings",
						fontSize  = "large",
                        desc = "Remember to Reload",
                        descStyle = "inline",
                        type = "description",
                        width = "full",
                       
                    },
                   
                    ResetBox = {
                        order = 1000,
                        name = "RESET ALL THE SETTINGS to DEFAULT ** RELOAD is required!!!",
                        desc = "Resets ALL THE SETTINGS to the default configuration. RELOAD is required!!!",
                        type = "toggle",
                        width = "full",
                        get = function() return db.ResetBox end,
                        set = function(info, value) db.ResetBox = value end
                    },

                }
            },
        }
    }
    return options
end